/* This file is auto-generated by opth-gen.awk.  */

#ifndef OPTIONS_H
#define OPTIONS_H

#include "flag-types.h"

#if !defined(IN_LIBGCC2) && !defined(IN_TARGET_LIBS) && !defined(IN_RTS)
#ifndef GENERATOR_FILE
#if !defined(GCC_DRIVER) && !defined(IN_LIBGCC2) && !defined(IN_TARGET_LIBS)
struct GTY(()) gcc_options
#else
struct gcc_options
#endif
{
#endif
#ifdef GENERATOR_FILE
extern HOST_WIDE_INT frame_larger_than_size;
#else
  HOST_WIDE_INT x_frame_larger_than_size;
#define frame_larger_than_size global_options.x_frame_larger_than_size
#endif
#ifdef GENERATOR_FILE
extern HOST_WIDE_INT larger_than_size;
#else
  HOST_WIDE_INT x_larger_than_size;
#define larger_than_size global_options.x_larger_than_size
#endif
#ifdef GENERATOR_FILE
extern bool exit_after_options;
#else
  bool x_exit_after_options;
#define exit_after_options global_options.x_exit_after_options
#endif
#ifdef GENERATOR_FILE
extern bool flag_dump_all_passed;
#else
  bool x_flag_dump_all_passed;
#define flag_dump_all_passed global_options.x_flag_dump_all_passed
#endif
#ifdef GENERATOR_FILE
extern bool flag_opts_finished;
#else
  bool x_flag_opts_finished;
#define flag_opts_finished global_options.x_flag_opts_finished
#endif
#ifdef GENERATOR_FILE
extern bool flag_warn_unused_result;
#else
  bool x_flag_warn_unused_result;
#define flag_warn_unused_result global_options.x_flag_warn_unused_result
#endif
#ifdef GENERATOR_FILE
extern bool use_gnu_debug_info_extensions;
#else
  bool x_use_gnu_debug_info_extensions;
#define use_gnu_debug_info_extensions global_options.x_use_gnu_debug_info_extensions
#endif
#ifdef GENERATOR_FILE
extern bool warn_frame_larger_than;
#else
  bool x_warn_frame_larger_than;
#define warn_frame_larger_than global_options.x_warn_frame_larger_than
#endif
#ifdef GENERATOR_FILE
extern bool warn_larger_than;
#else
  bool x_warn_larger_than;
#define warn_larger_than global_options.x_warn_larger_than
#endif
#ifdef GENERATOR_FILE
extern char *help_enum_printed;
#else
  char * x_help_enum_printed;
#define help_enum_printed global_options.x_help_enum_printed
#endif
#ifdef GENERATOR_FILE
extern char *help_printed;
#else
  char * x_help_printed;
#define help_printed global_options.x_help_printed
#endif
#ifdef GENERATOR_FILE
extern const char *main_input_basename;
#else
  const char * x_main_input_basename;
#define main_input_basename global_options.x_main_input_basename
#endif
#ifdef GENERATOR_FILE
extern const char *main_input_filename;
#else
  const char * x_main_input_filename;
#define main_input_filename global_options.x_main_input_filename
#endif
#ifdef GENERATOR_FILE
extern enum debug_info_levels debug_info_level;
#else
  enum debug_info_levels x_debug_info_level;
#define debug_info_level global_options.x_debug_info_level
#endif
#ifdef GENERATOR_FILE
extern enum debug_info_type write_symbols;
#else
  enum debug_info_type x_write_symbols;
#define write_symbols global_options.x_write_symbols
#endif
#ifdef GENERATOR_FILE
extern enum debug_struct_file debug_struct_generic[DINFO_USAGE_NUM_ENUMS];
#else
  enum debug_struct_file x_debug_struct_generic[DINFO_USAGE_NUM_ENUMS];
#define debug_struct_generic global_options.x_debug_struct_generic
#endif
#ifdef GENERATOR_FILE
extern enum debug_struct_file debug_struct_ordinary[DINFO_USAGE_NUM_ENUMS];
#else
  enum debug_struct_file x_debug_struct_ordinary[DINFO_USAGE_NUM_ENUMS];
#define debug_struct_ordinary global_options.x_debug_struct_ordinary
#endif
#ifdef GENERATOR_FILE
extern enum graph_dump_types graph_dump_format;
#else
  enum graph_dump_types x_graph_dump_format;
#define graph_dump_format global_options.x_graph_dump_format
#endif
#ifdef GENERATOR_FILE
extern enum stack_check_type flag_stack_check;
#else
  enum stack_check_type x_flag_stack_check;
#define flag_stack_check global_options.x_flag_stack_check
#endif
#ifdef GENERATOR_FILE
extern enum vect_verbosity_levels user_vect_verbosity_level;
#else
  enum vect_verbosity_levels x_user_vect_verbosity_level;
#define user_vect_verbosity_level global_options.x_user_vect_verbosity_level
#endif
#ifdef GENERATOR_FILE
extern int *param_values;
#else
  int * x_param_values;
#define param_values global_options.x_param_values
#endif
#ifdef GENERATOR_FILE
extern int flag_complex_method;
#else
  int x_flag_complex_method;
#define flag_complex_method global_options.x_flag_complex_method
#endif
#ifdef GENERATOR_FILE
extern int flag_debug_asm;
#else
  int x_flag_debug_asm;
#define flag_debug_asm global_options.x_flag_debug_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_rtl_in_asm;
#else
  int x_flag_dump_rtl_in_asm;
#define flag_dump_rtl_in_asm global_options.x_flag_dump_rtl_in_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_evaluation_order;
#else
  int x_flag_evaluation_order;
#define flag_evaluation_order global_options.x_flag_evaluation_order
#endif
#ifdef GENERATOR_FILE
extern int flag_gen_aux_info;
#else
  int x_flag_gen_aux_info;
#define flag_gen_aux_info global_options.x_flag_gen_aux_info
#endif
#ifdef GENERATOR_FILE
extern int flag_generate_lto;
#else
  int x_flag_generate_lto;
#define flag_generate_lto global_options.x_flag_generate_lto
#endif
#ifdef GENERATOR_FILE
extern int flag_print_asm_name;
#else
  int x_flag_print_asm_name;
#define flag_print_asm_name global_options.x_flag_print_asm_name
#endif
#ifdef GENERATOR_FILE
extern int flag_shlib;
#else
  int x_flag_shlib;
#define flag_shlib global_options.x_flag_shlib
#endif
#ifdef GENERATOR_FILE
extern int main_input_baselength;
#else
  int x_main_input_baselength;
#define main_input_baselength global_options.x_main_input_baselength
#endif
#ifdef GENERATOR_FILE
extern int optimize;
#else
  int x_optimize;
#define optimize global_options.x_optimize
#endif
#ifdef GENERATOR_FILE
extern int optimize_fast;
#else
  int x_optimize_fast;
#define optimize_fast global_options.x_optimize_fast
#endif
#ifdef GENERATOR_FILE
extern int optimize_size;
#else
  int x_optimize_size;
#define optimize_size global_options.x_optimize_size
#endif
#ifdef GENERATOR_FILE
extern int rtl_dump_and_exit;
#else
  int x_rtl_dump_and_exit;
#define rtl_dump_and_exit global_options.x_rtl_dump_and_exit
#endif
#ifdef GENERATOR_FILE
extern int target_flags;
#else
  int x_target_flags;
#define target_flags global_options.x_target_flags
#endif
#ifdef GENERATOR_FILE
extern unsigned int help_columns;
#else
  unsigned int x_help_columns;
#define help_columns global_options.x_help_columns
#endif
#ifdef GENERATOR_FILE
extern unsigned int initial_max_fld_align;
#else
  unsigned int x_initial_max_fld_align;
#define initial_max_fld_align global_options.x_initial_max_fld_align
#endif
#ifdef GENERATOR_FILE
extern void *flag_instrument_functions_exclude_files;
#else
  void * x_flag_instrument_functions_exclude_files;
#define flag_instrument_functions_exclude_files global_options.x_flag_instrument_functions_exclude_files
#endif
#ifdef GENERATOR_FILE
extern void *flag_instrument_functions_exclude_functions;
#else
  void * x_flag_instrument_functions_exclude_functions;
#define flag_instrument_functions_exclude_functions global_options.x_flag_instrument_functions_exclude_functions
#endif
#ifdef GENERATOR_FILE
extern int help_flag;
#else
  int x_help_flag;
#define help_flag global_options.x_help_flag
#endif
#ifdef GENERATOR_FILE
extern int flag_preprocess_only;
#else
  int x_flag_preprocess_only;
#define flag_preprocess_only global_options.x_flag_preprocess_only
#endif
#ifdef GENERATOR_FILE
extern int warn_abi;
#else
  int x_warn_abi;
#define warn_abi global_options.x_warn_abi
#endif
#ifdef GENERATOR_FILE
extern int warn_address;
#else
  int x_warn_address;
#define warn_address global_options.x_warn_address
#endif
#ifdef GENERATOR_FILE
extern int warn_aggregate_return;
#else
  int x_warn_aggregate_return;
#define warn_aggregate_return global_options.x_warn_aggregate_return
#endif
#ifdef GENERATOR_FILE
extern int warn_array_bounds;
#else
  int x_warn_array_bounds;
#define warn_array_bounds global_options.x_warn_array_bounds
#endif
#ifdef GENERATOR_FILE
extern int warn_assign_intercept;
#else
  int x_warn_assign_intercept;
#define warn_assign_intercept global_options.x_warn_assign_intercept
#endif
#ifdef GENERATOR_FILE
extern int warn_attributes;
#else
  int x_warn_attributes;
#define warn_attributes global_options.x_warn_attributes
#endif
#ifdef GENERATOR_FILE
extern int warn_bad_function_cast;
#else
  int x_warn_bad_function_cast;
#define warn_bad_function_cast global_options.x_warn_bad_function_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_cxx_compat;
#else
  int x_warn_cxx_compat;
#define warn_cxx_compat global_options.x_warn_cxx_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_cxx0x_compat;
#else
  int x_warn_cxx0x_compat;
#define warn_cxx0x_compat global_options.x_warn_cxx0x_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_cast_align;
#else
  int x_warn_cast_align;
#define warn_cast_align global_options.x_warn_cast_align
#endif
#ifdef GENERATOR_FILE
extern int warn_cast_qual;
#else
  int x_warn_cast_qual;
#define warn_cast_qual global_options.x_warn_cast_qual
#endif
#ifdef GENERATOR_FILE
extern int warn_char_subscripts;
#else
  int x_warn_char_subscripts;
#define warn_char_subscripts global_options.x_warn_char_subscripts
#endif
#ifdef GENERATOR_FILE
extern int warn_clobbered;
#else
  int x_warn_clobbered;
#define warn_clobbered global_options.x_warn_clobbered
#endif
#ifdef GENERATOR_FILE
extern int warn_conversion;
#else
  int x_warn_conversion;
#define warn_conversion global_options.x_warn_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_conversion_null;
#else
  int x_warn_conversion_null;
#define warn_conversion_null global_options.x_warn_conversion_null
#endif
#ifdef GENERATOR_FILE
extern int warn_coverage_mismatch;
#else
  int x_warn_coverage_mismatch;
#define warn_coverage_mismatch global_options.x_warn_coverage_mismatch
#endif
#ifdef GENERATOR_FILE
extern int warn_cpp;
#else
  int x_warn_cpp;
#define warn_cpp global_options.x_warn_cpp
#endif
#ifdef GENERATOR_FILE
extern int warn_ctor_dtor_privacy;
#else
  int x_warn_ctor_dtor_privacy;
#define warn_ctor_dtor_privacy global_options.x_warn_ctor_dtor_privacy
#endif
#ifdef GENERATOR_FILE
extern int warn_declaration_after_statement;
#else
  int x_warn_declaration_after_statement;
#define warn_declaration_after_statement global_options.x_warn_declaration_after_statement
#endif
#ifdef GENERATOR_FILE
extern int warn_deprecated;
#else
  int x_warn_deprecated;
#define warn_deprecated global_options.x_warn_deprecated
#endif
#ifdef GENERATOR_FILE
extern int warn_deprecated_decl;
#else
  int x_warn_deprecated_decl;
#define warn_deprecated_decl global_options.x_warn_deprecated_decl
#endif
#ifdef GENERATOR_FILE
extern int warn_disabled_optimization;
#else
  int x_warn_disabled_optimization;
#define warn_disabled_optimization global_options.x_warn_disabled_optimization
#endif
#ifdef GENERATOR_FILE
extern int warn_div_by_zero;
#else
  int x_warn_div_by_zero;
#define warn_div_by_zero global_options.x_warn_div_by_zero
#endif
#ifdef GENERATOR_FILE
extern int warn_double_promotion;
#else
  int x_warn_double_promotion;
#define warn_double_promotion global_options.x_warn_double_promotion
#endif
#ifdef GENERATOR_FILE
extern int warn_ecpp;
#else
  int x_warn_ecpp;
#define warn_ecpp global_options.x_warn_ecpp
#endif
#ifdef GENERATOR_FILE
extern int warn_empty_body;
#else
  int x_warn_empty_body;
#define warn_empty_body global_options.x_warn_empty_body
#endif
#ifdef GENERATOR_FILE
extern int warn_enum_compare;
#else
  int x_warn_enum_compare;
#define warn_enum_compare global_options.x_warn_enum_compare
#endif
#ifdef GENERATOR_FILE
extern int warnings_are_errors;
#else
  int x_warnings_are_errors;
#define warnings_are_errors global_options.x_warnings_are_errors
#endif
#ifdef GENERATOR_FILE
extern int extra_warnings;
#else
  int x_extra_warnings;
#define extra_warnings global_options.x_extra_warnings
#endif
#ifdef GENERATOR_FILE
extern int flag_fatal_errors;
#else
  int x_flag_fatal_errors;
#define flag_fatal_errors global_options.x_flag_fatal_errors
#endif
#ifdef GENERATOR_FILE
extern int warn_float_equal;
#else
  int x_warn_float_equal;
#define warn_float_equal global_options.x_warn_float_equal
#endif
#ifdef GENERATOR_FILE
extern int warn_format_contains_nul;
#else
  int x_warn_format_contains_nul;
#define warn_format_contains_nul global_options.x_warn_format_contains_nul
#endif
#ifdef GENERATOR_FILE
extern int warn_format_extra_args;
#else
  int x_warn_format_extra_args;
#define warn_format_extra_args global_options.x_warn_format_extra_args
#endif
#ifdef GENERATOR_FILE
extern int warn_format_nonliteral;
#else
  int x_warn_format_nonliteral;
#define warn_format_nonliteral global_options.x_warn_format_nonliteral
#endif
#ifdef GENERATOR_FILE
extern int warn_format_security;
#else
  int x_warn_format_security;
#define warn_format_security global_options.x_warn_format_security
#endif
#ifdef GENERATOR_FILE
extern int warn_format_y2k;
#else
  int x_warn_format_y2k;
#define warn_format_y2k global_options.x_warn_format_y2k
#endif
#ifdef GENERATOR_FILE
extern int warn_format_zero_length;
#else
  int x_warn_format_zero_length;
#define warn_format_zero_length global_options.x_warn_format_zero_length
#endif
#ifdef GENERATOR_FILE
extern int warn_ignored_qualifiers;
#else
  int x_warn_ignored_qualifiers;
#define warn_ignored_qualifiers global_options.x_warn_ignored_qualifiers
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit;
#else
  int x_warn_implicit;
#define warn_implicit global_options.x_warn_implicit
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit_function_declaration;
#else
  int x_warn_implicit_function_declaration;
#define warn_implicit_function_declaration global_options.x_warn_implicit_function_declaration
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit_int;
#else
  int x_warn_implicit_int;
#define warn_implicit_int global_options.x_warn_implicit_int
#endif
#ifdef GENERATOR_FILE
extern int warn_init_self;
#else
  int x_warn_init_self;
#define warn_init_self global_options.x_warn_init_self
#endif
#ifdef GENERATOR_FILE
extern int warn_inline;
#else
  int x_warn_inline;
#define warn_inline global_options.x_warn_inline
#endif
#ifdef GENERATOR_FILE
extern int warn_int_to_pointer_cast;
#else
  int x_warn_int_to_pointer_cast;
#define warn_int_to_pointer_cast global_options.x_warn_int_to_pointer_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_invalid_offsetof;
#else
  int x_warn_invalid_offsetof;
#define warn_invalid_offsetof global_options.x_warn_invalid_offsetof
#endif
#ifdef GENERATOR_FILE
extern int warn_jump_misses_init;
#else
  int x_warn_jump_misses_init;
#define warn_jump_misses_init global_options.x_warn_jump_misses_init
#endif
#ifdef GENERATOR_FILE
extern int warn_logical_op;
#else
  int x_warn_logical_op;
#define warn_logical_op global_options.x_warn_logical_op
#endif
#ifdef GENERATOR_FILE
extern int warn_long_long;
#else
  int x_warn_long_long;
#define warn_long_long global_options.x_warn_long_long
#endif
#ifdef GENERATOR_FILE
extern int warn_main;
#else
  int x_warn_main;
#define warn_main global_options.x_warn_main
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_braces;
#else
  int x_warn_missing_braces;
#define warn_missing_braces global_options.x_warn_missing_braces
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_declarations;
#else
  int x_warn_missing_declarations;
#define warn_missing_declarations global_options.x_warn_missing_declarations
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_field_initializers;
#else
  int x_warn_missing_field_initializers;
#define warn_missing_field_initializers global_options.x_warn_missing_field_initializers
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_format_attribute;
#else
  int x_warn_missing_format_attribute;
#define warn_missing_format_attribute global_options.x_warn_missing_format_attribute
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_noreturn;
#else
  int x_warn_missing_noreturn;
#define warn_missing_noreturn global_options.x_warn_missing_noreturn
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_parameter_type;
#else
  int x_warn_missing_parameter_type;
#define warn_missing_parameter_type global_options.x_warn_missing_parameter_type
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_prototypes;
#else
  int x_warn_missing_prototypes;
#define warn_missing_prototypes global_options.x_warn_missing_prototypes
#endif
#ifdef GENERATOR_FILE
extern int warn_mudflap;
#else
  int x_warn_mudflap;
#define warn_mudflap global_options.x_warn_mudflap
#endif
#ifdef GENERATOR_FILE
extern int warn_nested_externs;
#else
  int x_warn_nested_externs;
#define warn_nested_externs global_options.x_warn_nested_externs
#endif
#ifdef GENERATOR_FILE
extern int warn_noexcept;
#else
  int x_warn_noexcept;
#define warn_noexcept global_options.x_warn_noexcept
#endif
#ifdef GENERATOR_FILE
extern int warn_nontemplate_friend;
#else
  int x_warn_nontemplate_friend;
#define warn_nontemplate_friend global_options.x_warn_nontemplate_friend
#endif
#ifdef GENERATOR_FILE
extern int warn_nonvdtor;
#else
  int x_warn_nonvdtor;
#define warn_nonvdtor global_options.x_warn_nonvdtor
#endif
#ifdef GENERATOR_FILE
extern int warn_nonnull;
#else
  int x_warn_nonnull;
#define warn_nonnull global_options.x_warn_nonnull
#endif
#ifdef GENERATOR_FILE
extern int warn_old_style_cast;
#else
  int x_warn_old_style_cast;
#define warn_old_style_cast global_options.x_warn_old_style_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_old_style_declaration;
#else
  int x_warn_old_style_declaration;
#define warn_old_style_declaration global_options.x_warn_old_style_declaration
#endif
#ifdef GENERATOR_FILE
extern int warn_old_style_definition;
#else
  int x_warn_old_style_definition;
#define warn_old_style_definition global_options.x_warn_old_style_definition
#endif
#ifdef GENERATOR_FILE
extern int warn_overflow;
#else
  int x_warn_overflow;
#define warn_overflow global_options.x_warn_overflow
#endif
#ifdef GENERATOR_FILE
extern int warn_overlength_strings;
#else
  int x_warn_overlength_strings;
#define warn_overlength_strings global_options.x_warn_overlength_strings
#endif
#ifdef GENERATOR_FILE
extern int warn_overloaded_virtual;
#else
  int x_warn_overloaded_virtual;
#define warn_overloaded_virtual global_options.x_warn_overloaded_virtual
#endif
#ifdef GENERATOR_FILE
extern int warn_override_init;
#else
  int x_warn_override_init;
#define warn_override_init global_options.x_warn_override_init
#endif
#ifdef GENERATOR_FILE
extern int warn_packed;
#else
  int x_warn_packed;
#define warn_packed global_options.x_warn_packed
#endif
#ifdef GENERATOR_FILE
extern int warn_packed_bitfield_compat;
#else
  int x_warn_packed_bitfield_compat;
#define warn_packed_bitfield_compat global_options.x_warn_packed_bitfield_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_padded;
#else
  int x_warn_padded;
#define warn_padded global_options.x_warn_padded
#endif
#ifdef GENERATOR_FILE
extern int warn_parentheses;
#else
  int x_warn_parentheses;
#define warn_parentheses global_options.x_warn_parentheses
#endif
#ifdef GENERATOR_FILE
extern int warn_pmf2ptr;
#else
  int x_warn_pmf2ptr;
#define warn_pmf2ptr global_options.x_warn_pmf2ptr
#endif
#ifdef GENERATOR_FILE
extern int warn_pointer_arith;
#else
  int x_warn_pointer_arith;
#define warn_pointer_arith global_options.x_warn_pointer_arith
#endif
#ifdef GENERATOR_FILE
extern int warn_pointer_sign;
#else
  int x_warn_pointer_sign;
#define warn_pointer_sign global_options.x_warn_pointer_sign
#endif
#ifdef GENERATOR_FILE
extern int warn_pointer_to_int_cast;
#else
  int x_warn_pointer_to_int_cast;
#define warn_pointer_to_int_cast global_options.x_warn_pointer_to_int_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_pragmas;
#else
  int x_warn_pragmas;
#define warn_pragmas global_options.x_warn_pragmas
#endif
#ifdef GENERATOR_FILE
extern int warn_property_assign_default;
#else
  int x_warn_property_assign_default;
#define warn_property_assign_default global_options.x_warn_property_assign_default
#endif
#ifdef GENERATOR_FILE
extern int warn_protocol;
#else
  int x_warn_protocol;
#define warn_protocol global_options.x_warn_protocol
#endif
#ifdef GENERATOR_FILE
extern int warn_psabi;
#else
  int x_warn_psabi;
#define warn_psabi global_options.x_warn_psabi
#endif
#ifdef GENERATOR_FILE
extern int warn_redundant_decls;
#else
  int x_warn_redundant_decls;
#define warn_redundant_decls global_options.x_warn_redundant_decls
#endif
#ifdef GENERATOR_FILE
extern int warn_reorder;
#else
  int x_warn_reorder;
#define warn_reorder global_options.x_warn_reorder
#endif
#ifdef GENERATOR_FILE
extern int warn_return_type;
#else
  int x_warn_return_type;
#define warn_return_type global_options.x_warn_return_type
#endif
#ifdef GENERATOR_FILE
extern int warn_selector;
#else
  int x_warn_selector;
#define warn_selector global_options.x_warn_selector
#endif
#ifdef GENERATOR_FILE
extern int warn_sequence_point;
#else
  int x_warn_sequence_point;
#define warn_sequence_point global_options.x_warn_sequence_point
#endif
#ifdef GENERATOR_FILE
extern int warn_shadow;
#else
  int x_warn_shadow;
#define warn_shadow global_options.x_warn_shadow
#endif
#ifdef GENERATOR_FILE
extern int warn_sign_compare;
#else
  int x_warn_sign_compare;
#define warn_sign_compare global_options.x_warn_sign_compare
#endif
#ifdef GENERATOR_FILE
extern int warn_sign_conversion;
#else
  int x_warn_sign_conversion;
#define warn_sign_conversion global_options.x_warn_sign_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_sign_promo;
#else
  int x_warn_sign_promo;
#define warn_sign_promo global_options.x_warn_sign_promo
#endif
#ifdef GENERATOR_FILE
extern int warn_stack_protect;
#else
  int x_warn_stack_protect;
#define warn_stack_protect global_options.x_warn_stack_protect
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_aliasing;
#else
  int x_warn_strict_aliasing;
#define warn_strict_aliasing global_options.x_warn_strict_aliasing
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_null_sentinel;
#else
  int x_warn_strict_null_sentinel;
#define warn_strict_null_sentinel global_options.x_warn_strict_null_sentinel
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_overflow;
#else
  int x_warn_strict_overflow;
#define warn_strict_overflow global_options.x_warn_strict_overflow
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_prototypes;
#else
  int x_warn_strict_prototypes;
#define warn_strict_prototypes global_options.x_warn_strict_prototypes
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_selector_match;
#else
  int x_warn_strict_selector_match;
#define warn_strict_selector_match global_options.x_warn_strict_selector_match
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_const;
#else
  int x_warn_suggest_attribute_const;
#define warn_suggest_attribute_const global_options.x_warn_suggest_attribute_const
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_noreturn;
#else
  int x_warn_suggest_attribute_noreturn;
#define warn_suggest_attribute_noreturn global_options.x_warn_suggest_attribute_noreturn
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_pure;
#else
  int x_warn_suggest_attribute_pure;
#define warn_suggest_attribute_pure global_options.x_warn_suggest_attribute_pure
#endif
#ifdef GENERATOR_FILE
extern int warn_switch;
#else
  int x_warn_switch;
#define warn_switch global_options.x_warn_switch
#endif
#ifdef GENERATOR_FILE
extern int warn_switch_default;
#else
  int x_warn_switch_default;
#define warn_switch_default global_options.x_warn_switch_default
#endif
#ifdef GENERATOR_FILE
extern int warn_switch_enum;
#else
  int x_warn_switch_enum;
#define warn_switch_enum global_options.x_warn_switch_enum
#endif
#ifdef GENERATOR_FILE
extern int warn_sync_nand;
#else
  int x_warn_sync_nand;
#define warn_sync_nand global_options.x_warn_sync_nand
#endif
#ifdef GENERATOR_FILE
extern int warn_synth;
#else
  int x_warn_synth;
#define warn_synth global_options.x_warn_synth
#endif
#ifdef GENERATOR_FILE
extern int warn_system_headers;
#else
  int x_warn_system_headers;
#define warn_system_headers global_options.x_warn_system_headers
#endif
#ifdef GENERATOR_FILE
extern int warn_traditional;
#else
  int x_warn_traditional;
#define warn_traditional global_options.x_warn_traditional
#endif
#ifdef GENERATOR_FILE
extern int warn_traditional_conversion;
#else
  int x_warn_traditional_conversion;
#define warn_traditional_conversion global_options.x_warn_traditional_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_trampolines;
#else
  int x_warn_trampolines;
#define warn_trampolines global_options.x_warn_trampolines
#endif
#ifdef GENERATOR_FILE
extern int warn_type_limits;
#else
  int x_warn_type_limits;
#define warn_type_limits global_options.x_warn_type_limits
#endif
#ifdef GENERATOR_FILE
extern int warn_undeclared_selector;
#else
  int x_warn_undeclared_selector;
#define warn_undeclared_selector global_options.x_warn_undeclared_selector
#endif
#ifdef GENERATOR_FILE
extern int warn_uninitialized;
#else
  int x_warn_uninitialized;
#define warn_uninitialized global_options.x_warn_uninitialized
#endif
#ifdef GENERATOR_FILE
extern int warn_unsafe_loop_optimizations;
#else
  int x_warn_unsafe_loop_optimizations;
#define warn_unsafe_loop_optimizations global_options.x_warn_unsafe_loop_optimizations
#endif
#ifdef GENERATOR_FILE
extern int warn_unsuffixed_float_constants;
#else
  int x_warn_unsuffixed_float_constants;
#define warn_unsuffixed_float_constants global_options.x_warn_unsuffixed_float_constants
#endif
#ifdef GENERATOR_FILE
extern int warn_unused;
#else
  int x_warn_unused;
#define warn_unused global_options.x_warn_unused
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_but_set_parameter;
#else
  int x_warn_unused_but_set_parameter;
#define warn_unused_but_set_parameter global_options.x_warn_unused_but_set_parameter
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_but_set_variable;
#else
  int x_warn_unused_but_set_variable;
#define warn_unused_but_set_variable global_options.x_warn_unused_but_set_variable
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_function;
#else
  int x_warn_unused_function;
#define warn_unused_function global_options.x_warn_unused_function
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_label;
#else
  int x_warn_unused_label;
#define warn_unused_label global_options.x_warn_unused_label
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_parameter;
#else
  int x_warn_unused_parameter;
#define warn_unused_parameter global_options.x_warn_unused_parameter
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_result;
#else
  int x_warn_unused_result;
#define warn_unused_result global_options.x_warn_unused_result
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_value;
#else
  int x_warn_unused_value;
#define warn_unused_value global_options.x_warn_unused_value
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_variable;
#else
  int x_warn_unused_variable;
#define warn_unused_variable global_options.x_warn_unused_variable
#endif
#ifdef GENERATOR_FILE
extern int warn_vla;
#else
  int x_warn_vla;
#define warn_vla global_options.x_warn_vla
#endif
#ifdef GENERATOR_FILE
extern int warn_volatile_register_var;
#else
  int x_warn_volatile_register_var;
#define warn_volatile_register_var global_options.x_warn_volatile_register_var
#endif
#ifdef GENERATOR_FILE
extern int warn_write_strings;
#else
  int x_warn_write_strings;
#define warn_write_strings global_options.x_warn_write_strings
#endif
#ifdef GENERATOR_FILE
extern const char *aux_info_file_name;
#else
  const char *x_aux_info_file_name;
#define aux_info_file_name global_options.x_aux_info_file_name
#endif
#ifdef GENERATOR_FILE
extern const char *aux_base_name;
#else
  const char *x_aux_base_name;
#define aux_base_name global_options.x_aux_base_name
#endif
#ifdef GENERATOR_FILE
extern const char *dump_base_name;
#else
  const char *x_dump_base_name;
#define dump_base_name global_options.x_dump_base_name
#endif
#ifdef GENERATOR_FILE
extern const char *dump_dir_name;
#else
  const char *x_dump_dir_name;
#define dump_dir_name global_options.x_dump_dir_name
#endif
#ifdef GENERATOR_FILE
extern int flag_pic;
#else
  int x_flag_pic;
#define flag_pic global_options.x_flag_pic
#endif
#ifdef GENERATOR_FILE
extern int flag_pie;
#else
  int x_flag_pie;
#define flag_pie global_options.x_flag_pie
#endif
#ifdef GENERATOR_FILE
extern int flag_abi_version;
#else
  int x_flag_abi_version;
#define flag_abi_version global_options.x_flag_abi_version
#endif
#ifdef GENERATOR_FILE
extern int flag_access_control;
#else
  int x_flag_access_control;
#define flag_access_control global_options.x_flag_access_control
#endif
#ifdef GENERATOR_FILE
extern int align_functions;
#else
  int x_align_functions;
#define align_functions global_options.x_align_functions
#endif
#ifdef GENERATOR_FILE
extern int align_jumps;
#else
  int x_align_jumps;
#define align_jumps global_options.x_align_jumps
#endif
#ifdef GENERATOR_FILE
extern int align_labels;
#else
  int x_align_labels;
#define align_labels global_options.x_align_labels
#endif
#ifdef GENERATOR_FILE
extern int align_loops;
#else
  int x_align_loops;
#define align_loops global_options.x_align_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_no_asm;
#else
  int x_flag_no_asm;
#define flag_no_asm global_options.x_flag_no_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_associative_math;
#else
  int x_flag_associative_math;
#define flag_associative_math global_options.x_flag_associative_math
#endif
#ifdef GENERATOR_FILE
extern int flag_asynchronous_unwind_tables;
#else
  int x_flag_asynchronous_unwind_tables;
#define flag_asynchronous_unwind_tables global_options.x_flag_asynchronous_unwind_tables
#endif
#ifdef GENERATOR_FILE
extern int flag_auto_inc_dec;
#else
  int x_flag_auto_inc_dec;
#define flag_auto_inc_dec global_options.x_flag_auto_inc_dec
#endif
#ifdef GENERATOR_FILE
extern int flag_bounds_check;
#else
  int x_flag_bounds_check;
#define flag_bounds_check global_options.x_flag_bounds_check
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_on_count_reg;
#else
  int x_flag_branch_on_count_reg;
#define flag_branch_on_count_reg global_options.x_flag_branch_on_count_reg
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_probabilities;
#else
  int x_flag_branch_probabilities;
#define flag_branch_probabilities global_options.x_flag_branch_probabilities
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_target_load_optimize;
#else
  int x_flag_branch_target_load_optimize;
#define flag_branch_target_load_optimize global_options.x_flag_branch_target_load_optimize
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_target_load_optimize2;
#else
  int x_flag_branch_target_load_optimize2;
#define flag_branch_target_load_optimize2 global_options.x_flag_branch_target_load_optimize2
#endif
#ifdef GENERATOR_FILE
extern int flag_btr_bb_exclusive;
#else
  int x_flag_btr_bb_exclusive;
#define flag_btr_bb_exclusive global_options.x_flag_btr_bb_exclusive
#endif
#ifdef GENERATOR_FILE
extern int flag_no_builtin;
#else
  int x_flag_no_builtin;
#define flag_no_builtin global_options.x_flag_no_builtin
#endif
#ifdef GENERATOR_FILE
extern void *common_deferred_options;
#else
  void *x_common_deferred_options;
#define common_deferred_options global_options.x_common_deferred_options
#endif
#ifdef GENERATOR_FILE
extern int flag_caller_saves;
#else
  int x_flag_caller_saves;
#define flag_caller_saves global_options.x_flag_caller_saves
#endif
#ifdef GENERATOR_FILE
extern int flag_check_data_deps;
#else
  int x_flag_check_data_deps;
#define flag_check_data_deps global_options.x_flag_check_data_deps
#endif
#ifdef GENERATOR_FILE
extern int flag_check_new;
#else
  int x_flag_check_new;
#define flag_check_new global_options.x_flag_check_new
#endif
#ifdef GENERATOR_FILE
extern int flag_combine_stack_adjustments;
#else
  int x_flag_combine_stack_adjustments;
#define flag_combine_stack_adjustments global_options.x_flag_combine_stack_adjustments
#endif
#ifdef GENERATOR_FILE
extern int flag_no_common;
#else
  int x_flag_no_common;
#define flag_no_common global_options.x_flag_no_common
#endif
#ifdef GENERATOR_FILE
extern int flag_compare_debug;
#else
  int x_flag_compare_debug;
#define flag_compare_debug global_options.x_flag_compare_debug
#endif
#ifdef GENERATOR_FILE
extern const char *flag_compare_debug_opt;
#else
  const char *x_flag_compare_debug_opt;
#define flag_compare_debug_opt global_options.x_flag_compare_debug_opt
#endif
#ifdef GENERATOR_FILE
extern int flag_compare_elim_after_reload;
#else
  int x_flag_compare_elim_after_reload;
#define flag_compare_elim_after_reload global_options.x_flag_compare_elim_after_reload
#endif
#ifdef GENERATOR_FILE
extern int flag_conserve_space;
#else
  int x_flag_conserve_space;
#define flag_conserve_space global_options.x_flag_conserve_space
#endif
#ifdef GENERATOR_FILE
extern int flag_conserve_stack;
#else
  int x_flag_conserve_stack;
#define flag_conserve_stack global_options.x_flag_conserve_stack
#endif
#ifdef GENERATOR_FILE
extern int max_constexpr_depth;
#else
  int x_max_constexpr_depth;
#define max_constexpr_depth global_options.x_max_constexpr_depth
#endif
#ifdef GENERATOR_FILE
extern int flag_cprop_registers;
#else
  int x_flag_cprop_registers;
#define flag_cprop_registers global_options.x_flag_cprop_registers
#endif
#ifdef GENERATOR_FILE
extern int flag_crossjumping;
#else
  int x_flag_crossjumping;
#define flag_crossjumping global_options.x_flag_crossjumping
#endif
#ifdef GENERATOR_FILE
extern int flag_cse_follow_jumps;
#else
  int x_flag_cse_follow_jumps;
#define flag_cse_follow_jumps global_options.x_flag_cse_follow_jumps
#endif
#ifdef GENERATOR_FILE
extern int flag_cx_fortran_rules;
#else
  int x_flag_cx_fortran_rules;
#define flag_cx_fortran_rules global_options.x_flag_cx_fortran_rules
#endif
#ifdef GENERATOR_FILE
extern int flag_cx_limited_range;
#else
  int x_flag_cx_limited_range;
#define flag_cx_limited_range global_options.x_flag_cx_limited_range
#endif
#ifdef GENERATOR_FILE
extern int flag_data_sections;
#else
  int x_flag_data_sections;
#define flag_data_sections global_options.x_flag_data_sections
#endif
#ifdef GENERATOR_FILE
extern int flag_dce;
#else
  int x_flag_dce;
#define flag_dce global_options.x_flag_dce
#endif
#ifdef GENERATOR_FILE
extern int flag_deduce_init_list;
#else
  int x_flag_deduce_init_list;
#define flag_deduce_init_list global_options.x_flag_deduce_init_list
#endif
#ifdef GENERATOR_FILE
extern int flag_defer_pop;
#else
  int x_flag_defer_pop;
#define flag_defer_pop global_options.x_flag_defer_pop
#endif
#ifdef GENERATOR_FILE
extern int flag_delayed_branch;
#else
  int x_flag_delayed_branch;
#define flag_delayed_branch global_options.x_flag_delayed_branch
#endif
#ifdef GENERATOR_FILE
extern int flag_delete_null_pointer_checks;
#else
  int x_flag_delete_null_pointer_checks;
#define flag_delete_null_pointer_checks global_options.x_flag_delete_null_pointer_checks
#endif
#ifdef GENERATOR_FILE
extern int flag_devirtualize;
#else
  int x_flag_devirtualize;
#define flag_devirtualize global_options.x_flag_devirtualize
#endif
#ifdef GENERATOR_FILE
extern int flag_diagnostics_show_option;
#else
  int x_flag_diagnostics_show_option;
#define flag_diagnostics_show_option global_options.x_flag_diagnostics_show_option
#endif
#ifdef GENERATOR_FILE
extern int flag_dse;
#else
  int x_flag_dse;
#define flag_dse global_options.x_flag_dse
#endif
#ifdef GENERATOR_FILE
extern const char *flag_dump_final_insns;
#else
  const char *x_flag_dump_final_insns;
#define flag_dump_final_insns global_options.x_flag_dump_final_insns
#endif
#ifdef GENERATOR_FILE
extern const char *flag_dump_go_spec;
#else
  const char *x_flag_dump_go_spec;
#define flag_dump_go_spec global_options.x_flag_dump_go_spec
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_noaddr;
#else
  int x_flag_dump_noaddr;
#define flag_dump_noaddr global_options.x_flag_dump_noaddr
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_unnumbered;
#else
  int x_flag_dump_unnumbered;
#define flag_dump_unnumbered global_options.x_flag_dump_unnumbered
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_unnumbered_links;
#else
  int x_flag_dump_unnumbered_links;
#define flag_dump_unnumbered_links global_options.x_flag_dump_unnumbered_links
#endif
#ifdef GENERATOR_FILE
extern int flag_dwarf2_cfi_asm;
#else
  int x_flag_dwarf2_cfi_asm;
#define flag_dwarf2_cfi_asm global_options.x_flag_dwarf2_cfi_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_early_inlining;
#else
  int x_flag_early_inlining;
#define flag_early_inlining global_options.x_flag_early_inlining
#endif
#ifdef GENERATOR_FILE
extern int flag_elide_constructors;
#else
  int x_flag_elide_constructors;
#define flag_elide_constructors global_options.x_flag_elide_constructors
#endif
#ifdef GENERATOR_FILE
extern int flag_eliminate_dwarf2_dups;
#else
  int x_flag_eliminate_dwarf2_dups;
#define flag_eliminate_dwarf2_dups global_options.x_flag_eliminate_dwarf2_dups
#endif
#ifdef GENERATOR_FILE
extern int flag_debug_only_used_symbols;
#else
  int x_flag_debug_only_used_symbols;
#define flag_debug_only_used_symbols global_options.x_flag_debug_only_used_symbols
#endif
#ifdef GENERATOR_FILE
extern int flag_eliminate_unused_debug_types;
#else
  int x_flag_eliminate_unused_debug_types;
#define flag_eliminate_unused_debug_types global_options.x_flag_eliminate_unused_debug_types
#endif
#ifdef GENERATOR_FILE
extern int flag_emit_class_debug_always;
#else
  int x_flag_emit_class_debug_always;
#define flag_emit_class_debug_always global_options.x_flag_emit_class_debug_always
#endif
#ifdef GENERATOR_FILE
extern int flag_enable_icf_debug;
#else
  int x_flag_enable_icf_debug;
#define flag_enable_icf_debug global_options.x_flag_enable_icf_debug
#endif
#ifdef GENERATOR_FILE
extern int flag_enforce_eh_specs;
#else
  int x_flag_enforce_eh_specs;
#define flag_enforce_eh_specs global_options.x_flag_enforce_eh_specs
#endif
#ifdef GENERATOR_FILE
extern int flag_exceptions;
#else
  int x_flag_exceptions;
#define flag_exceptions global_options.x_flag_exceptions
#endif
#ifdef GENERATOR_FILE
extern enum excess_precision flag_excess_precision_cmdline;
#else
  enum excess_precision x_flag_excess_precision_cmdline;
#define flag_excess_precision_cmdline global_options.x_flag_excess_precision_cmdline
#endif
#ifdef GENERATOR_FILE
extern int flag_expensive_optimizations;
#else
  int x_flag_expensive_optimizations;
#define flag_expensive_optimizations global_options.x_flag_expensive_optimizations
#endif
#ifdef GENERATOR_FILE
extern int flag_finite_math_only;
#else
  int x_flag_finite_math_only;
#define flag_finite_math_only global_options.x_flag_finite_math_only
#endif
#ifdef GENERATOR_FILE
extern int flag_float_store;
#else
  int x_flag_float_store;
#define flag_float_store global_options.x_flag_float_store
#endif
#ifdef GENERATOR_FILE
extern int flag_new_for_scope;
#else
  int x_flag_new_for_scope;
#define flag_new_for_scope global_options.x_flag_new_for_scope
#endif
#ifdef GENERATOR_FILE
extern int flag_forward_propagate;
#else
  int x_flag_forward_propagate;
#define flag_forward_propagate global_options.x_flag_forward_propagate
#endif
#ifdef GENERATOR_FILE
extern enum fp_contract_mode flag_fp_contract_mode;
#else
  enum fp_contract_mode x_flag_fp_contract_mode;
#define flag_fp_contract_mode global_options.x_flag_fp_contract_mode
#endif
#ifdef GENERATOR_FILE
extern int flag_friend_injection;
#else
  int x_flag_friend_injection;
#define flag_friend_injection global_options.x_flag_friend_injection
#endif
#ifdef GENERATOR_FILE
extern int flag_no_function_cse;
#else
  int x_flag_no_function_cse;
#define flag_no_function_cse global_options.x_flag_no_function_cse
#endif
#ifdef GENERATOR_FILE
extern int flag_function_sections;
#else
  int x_flag_function_sections;
#define flag_function_sections global_options.x_flag_function_sections
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse;
#else
  int x_flag_gcse;
#define flag_gcse global_options.x_flag_gcse
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_after_reload;
#else
  int x_flag_gcse_after_reload;
#define flag_gcse_after_reload global_options.x_flag_gcse_after_reload
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_las;
#else
  int x_flag_gcse_las;
#define flag_gcse_las global_options.x_flag_gcse_las
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_lm;
#else
  int x_flag_gcse_lm;
#define flag_gcse_lm global_options.x_flag_gcse_lm
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_sm;
#else
  int x_flag_gcse_sm;
#define flag_gcse_sm global_options.x_flag_gcse_sm
#endif
#ifdef GENERATOR_FILE
extern int flag_no_gnu_keywords;
#else
  int x_flag_no_gnu_keywords;
#define flag_no_gnu_keywords global_options.x_flag_no_gnu_keywords
#endif
#ifdef GENERATOR_FILE
extern int flag_gnu89_inline;
#else
  int x_flag_gnu89_inline;
#define flag_gnu89_inline global_options.x_flag_gnu89_inline
#endif
#ifdef GENERATOR_FILE
extern int flag_graphite;
#else
  int x_flag_graphite;
#define flag_graphite global_options.x_flag_graphite
#endif
#ifdef GENERATOR_FILE
extern int flag_graphite_identity;
#else
  int x_flag_graphite_identity;
#define flag_graphite_identity global_options.x_flag_graphite_identity
#endif
#ifdef GENERATOR_FILE
extern int flag_guess_branch_prob;
#else
  int x_flag_guess_branch_prob;
#define flag_guess_branch_prob global_options.x_flag_guess_branch_prob
#endif
#ifdef GENERATOR_FILE
extern int flag_no_ident;
#else
  int x_flag_no_ident;
#define flag_no_ident global_options.x_flag_no_ident
#endif
#ifdef GENERATOR_FILE
extern int flag_if_conversion;
#else
  int x_flag_if_conversion;
#define flag_if_conversion global_options.x_flag_if_conversion
#endif
#ifdef GENERATOR_FILE
extern int flag_if_conversion2;
#else
  int x_flag_if_conversion2;
#define flag_if_conversion2 global_options.x_flag_if_conversion2
#endif
#ifdef GENERATOR_FILE
extern int flag_implement_inlines;
#else
  int x_flag_implement_inlines;
#define flag_implement_inlines global_options.x_flag_implement_inlines
#endif
#ifdef GENERATOR_FILE
extern int flag_implicit_inline_templates;
#else
  int x_flag_implicit_inline_templates;
#define flag_implicit_inline_templates global_options.x_flag_implicit_inline_templates
#endif
#ifdef GENERATOR_FILE
extern int flag_implicit_templates;
#else
  int x_flag_implicit_templates;
#define flag_implicit_templates global_options.x_flag_implicit_templates
#endif
#ifdef GENERATOR_FILE
extern int flag_indirect_inlining;
#else
  int x_flag_indirect_inlining;
#define flag_indirect_inlining global_options.x_flag_indirect_inlining
#endif
#ifdef GENERATOR_FILE
extern int flag_inhibit_size_directive;
#else
  int x_flag_inhibit_size_directive;
#define flag_inhibit_size_directive global_options.x_flag_inhibit_size_directive
#endif
#ifdef GENERATOR_FILE
extern int flag_no_inline;
#else
  int x_flag_no_inline;
#define flag_no_inline global_options.x_flag_no_inline
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_functions;
#else
  int x_flag_inline_functions;
#define flag_inline_functions global_options.x_flag_inline_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_functions_called_once;
#else
  int x_flag_inline_functions_called_once;
#define flag_inline_functions_called_once global_options.x_flag_inline_functions_called_once
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_small_functions;
#else
  int x_flag_inline_small_functions;
#define flag_inline_small_functions global_options.x_flag_inline_small_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_instrument_function_entry_exit;
#else
  int x_flag_instrument_function_entry_exit;
#define flag_instrument_function_entry_exit global_options.x_flag_instrument_function_entry_exit
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_cp;
#else
  int x_flag_ipa_cp;
#define flag_ipa_cp global_options.x_flag_ipa_cp
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_cp_clone;
#else
  int x_flag_ipa_cp_clone;
#define flag_ipa_cp_clone global_options.x_flag_ipa_cp_clone
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_matrix_reorg;
#else
  int x_flag_ipa_matrix_reorg;
#define flag_ipa_matrix_reorg global_options.x_flag_ipa_matrix_reorg
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_profile;
#else
  int x_flag_ipa_profile;
#define flag_ipa_profile global_options.x_flag_ipa_profile
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_pta;
#else
  int x_flag_ipa_pta;
#define flag_ipa_pta global_options.x_flag_ipa_pta
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_pure_const;
#else
  int x_flag_ipa_pure_const;
#define flag_ipa_pure_const global_options.x_flag_ipa_pure_const
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_reference;
#else
  int x_flag_ipa_reference;
#define flag_ipa_reference global_options.x_flag_ipa_reference
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_sra;
#else
  int x_flag_ipa_sra;
#define flag_ipa_sra global_options.x_flag_ipa_sra
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_struct_reorg;
#else
  int x_flag_ipa_struct_reorg;
#define flag_ipa_struct_reorg global_options.x_flag_ipa_struct_reorg
#endif
#ifdef GENERATOR_FILE
extern enum ira_algorithm flag_ira_algorithm;
#else
  enum ira_algorithm x_flag_ira_algorithm;
#define flag_ira_algorithm global_options.x_flag_ira_algorithm
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_loop_pressure;
#else
  int x_flag_ira_loop_pressure;
#define flag_ira_loop_pressure global_options.x_flag_ira_loop_pressure
#endif
#ifdef GENERATOR_FILE
extern enum ira_region flag_ira_region;
#else
  enum ira_region x_flag_ira_region;
#define flag_ira_region global_options.x_flag_ira_region
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_share_save_slots;
#else
  int x_flag_ira_share_save_slots;
#define flag_ira_share_save_slots global_options.x_flag_ira_share_save_slots
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_share_spill_slots;
#else
  int x_flag_ira_share_spill_slots;
#define flag_ira_share_spill_slots global_options.x_flag_ira_share_spill_slots
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_verbose;
#else
  int x_flag_ira_verbose;
#define flag_ira_verbose global_options.x_flag_ira_verbose
#endif
#ifdef GENERATOR_FILE
extern int flag_ivopts;
#else
  int x_flag_ivopts;
#define flag_ivopts global_options.x_flag_ivopts
#endif
#ifdef GENERATOR_FILE
extern int flag_jump_tables;
#else
  int x_flag_jump_tables;
#define flag_jump_tables global_options.x_flag_jump_tables
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_inline_dllexport;
#else
  int x_flag_keep_inline_dllexport;
#define flag_keep_inline_dllexport global_options.x_flag_keep_inline_dllexport
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_inline_functions;
#else
  int x_flag_keep_inline_functions;
#define flag_keep_inline_functions global_options.x_flag_keep_inline_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_static_consts;
#else
  int x_flag_keep_static_consts;
#define flag_keep_static_consts global_options.x_flag_keep_static_consts
#endif
#ifdef GENERATOR_FILE
extern int flag_lax_vector_conversions;
#else
  int x_flag_lax_vector_conversions;
#define flag_lax_vector_conversions global_options.x_flag_lax_vector_conversions
#endif
#ifdef GENERATOR_FILE
extern int flag_leading_underscore;
#else
  int x_flag_leading_underscore;
#define flag_leading_underscore global_options.x_flag_leading_underscore
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_block;
#else
  int x_flag_loop_block;
#define flag_loop_block global_options.x_flag_loop_block
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_flatten;
#else
  int x_flag_loop_flatten;
#define flag_loop_flatten global_options.x_flag_loop_flatten
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_interchange;
#else
  int x_flag_loop_interchange;
#define flag_loop_interchange global_options.x_flag_loop_interchange
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_parallelize_all;
#else
  int x_flag_loop_parallelize_all;
#define flag_loop_parallelize_all global_options.x_flag_loop_parallelize_all
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_strip_mine;
#else
  int x_flag_loop_strip_mine;
#define flag_loop_strip_mine global_options.x_flag_loop_strip_mine
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_compression_level;
#else
  int x_flag_lto_compression_level;
#define flag_lto_compression_level global_options.x_flag_lto_compression_level
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_partition_1to1;
#else
  int x_flag_lto_partition_1to1;
#define flag_lto_partition_1to1 global_options.x_flag_lto_partition_1to1
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_partition_balanced;
#else
  int x_flag_lto_partition_balanced;
#define flag_lto_partition_balanced global_options.x_flag_lto_partition_balanced
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_partition_none;
#else
  int x_flag_lto_partition_none;
#define flag_lto_partition_none global_options.x_flag_lto_partition_none
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_report;
#else
  int x_flag_lto_report;
#define flag_lto_report global_options.x_flag_lto_report
#endif
#ifdef GENERATOR_FILE
extern const char *flag_lto;
#else
  const char *x_flag_lto;
#define flag_lto global_options.x_flag_lto
#endif
#ifdef GENERATOR_FILE
extern int flag_ltrans;
#else
  int x_flag_ltrans;
#define flag_ltrans global_options.x_flag_ltrans
#endif
#ifdef GENERATOR_FILE
extern const char *ltrans_output_list;
#else
  const char *x_ltrans_output_list;
#define ltrans_output_list global_options.x_ltrans_output_list
#endif
#ifdef GENERATOR_FILE
extern int flag_errno_math;
#else
  int x_flag_errno_math;
#define flag_errno_math global_options.x_flag_errno_math
#endif
#ifdef GENERATOR_FILE
extern int flag_max_errors;
#else
  int x_flag_max_errors;
#define flag_max_errors global_options.x_flag_max_errors
#endif
#ifdef GENERATOR_FILE
extern int mem_report;
#else
  int x_mem_report;
#define mem_report global_options.x_mem_report
#endif
#ifdef GENERATOR_FILE
extern int flag_merge_constants;
#else
  int x_flag_merge_constants;
#define flag_merge_constants global_options.x_flag_merge_constants
#endif
#ifdef GENERATOR_FILE
extern int flag_merge_debug_strings;
#else
  int x_flag_merge_debug_strings;
#define flag_merge_debug_strings global_options.x_flag_merge_debug_strings
#endif
#ifdef GENERATOR_FILE
extern int flag_modulo_sched;
#else
  int x_flag_modulo_sched;
#define flag_modulo_sched global_options.x_flag_modulo_sched
#endif
#ifdef GENERATOR_FILE
extern int flag_modulo_sched_allow_regmoves;
#else
  int x_flag_modulo_sched_allow_regmoves;
#define flag_modulo_sched_allow_regmoves global_options.x_flag_modulo_sched_allow_regmoves
#endif
#ifdef GENERATOR_FILE
extern int flag_move_loop_invariants;
#else
  int x_flag_move_loop_invariants;
#define flag_move_loop_invariants global_options.x_flag_move_loop_invariants
#endif
#ifdef GENERATOR_FILE
extern int flag_ms_extensions;
#else
  int x_flag_ms_extensions;
#define flag_ms_extensions global_options.x_flag_ms_extensions
#endif
#ifdef GENERATOR_FILE
extern int flag_mudflap;
#else
  int x_flag_mudflap;
#define flag_mudflap global_options.x_flag_mudflap
#endif
#ifdef GENERATOR_FILE
extern int flag_mudflap_ignore_reads;
#else
  int x_flag_mudflap_ignore_reads;
#define flag_mudflap_ignore_reads global_options.x_flag_mudflap_ignore_reads
#endif
#ifdef GENERATOR_FILE
extern int flag_nil_receivers;
#else
  int x_flag_nil_receivers;
#define flag_nil_receivers global_options.x_flag_nil_receivers
#endif
#ifdef GENERATOR_FILE
extern int flag_non_call_exceptions;
#else
  int x_flag_non_call_exceptions;
#define flag_non_call_exceptions global_options.x_flag_non_call_exceptions
#endif
#ifdef GENERATOR_FILE
extern int flag_no_nonansi_builtin;
#else
  int x_flag_no_nonansi_builtin;
#define flag_no_nonansi_builtin global_options.x_flag_no_nonansi_builtin
#endif
#ifdef GENERATOR_FILE
extern int flag_nothrow_opt;
#else
  int x_flag_nothrow_opt;
#define flag_nothrow_opt global_options.x_flag_nothrow_opt
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_abi;
#else
  int x_flag_objc_abi;
#define flag_objc_abi global_options.x_flag_objc_abi
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_call_cxx_cdtors;
#else
  int x_flag_objc_call_cxx_cdtors;
#define flag_objc_call_cxx_cdtors global_options.x_flag_objc_call_cxx_cdtors
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_direct_dispatch;
#else
  int x_flag_objc_direct_dispatch;
#define flag_objc_direct_dispatch global_options.x_flag_objc_direct_dispatch
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_exceptions;
#else
  int x_flag_objc_exceptions;
#define flag_objc_exceptions global_options.x_flag_objc_exceptions
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_gc;
#else
  int x_flag_objc_gc;
#define flag_objc_gc global_options.x_flag_objc_gc
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_nilcheck;
#else
  int x_flag_objc_nilcheck;
#define flag_objc_nilcheck global_options.x_flag_objc_nilcheck
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_sjlj_exceptions;
#else
  int x_flag_objc_sjlj_exceptions;
#define flag_objc_sjlj_exceptions global_options.x_flag_objc_sjlj_exceptions
#endif
#ifdef GENERATOR_FILE
extern int flag_objc1_only;
#else
  int x_flag_objc1_only;
#define flag_objc1_only global_options.x_flag_objc1_only
#endif
#ifdef GENERATOR_FILE
extern int flag_omit_frame_pointer;
#else
  int x_flag_omit_frame_pointer;
#define flag_omit_frame_pointer global_options.x_flag_omit_frame_pointer
#endif
#ifdef GENERATOR_FILE
extern int flag_openmp;
#else
  int x_flag_openmp;
#define flag_openmp global_options.x_flag_openmp
#endif
#ifdef GENERATOR_FILE
extern int flag_regmove;
#else
  int x_flag_regmove;
#define flag_regmove global_options.x_flag_regmove
#endif
#ifdef GENERATOR_FILE
extern int flag_optimize_sibling_calls;
#else
  int x_flag_optimize_sibling_calls;
#define flag_optimize_sibling_calls global_options.x_flag_optimize_sibling_calls
#endif
#ifdef GENERATOR_FILE
extern int flag_pack_struct;
#else
  int x_flag_pack_struct;
#define flag_pack_struct global_options.x_flag_pack_struct
#endif
#ifdef GENERATOR_FILE
extern int flag_partial_inlining;
#else
  int x_flag_partial_inlining;
#define flag_partial_inlining global_options.x_flag_partial_inlining
#endif
#ifdef GENERATOR_FILE
extern int flag_pcc_struct_return;
#else
  int x_flag_pcc_struct_return;
#define flag_pcc_struct_return global_options.x_flag_pcc_struct_return
#endif
#ifdef GENERATOR_FILE
extern int flag_peel_loops;
#else
  int x_flag_peel_loops;
#define flag_peel_loops global_options.x_flag_peel_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_no_peephole;
#else
  int x_flag_no_peephole;
#define flag_no_peephole global_options.x_flag_no_peephole
#endif
#ifdef GENERATOR_FILE
extern int flag_peephole2;
#else
  int x_flag_peephole2;
#define flag_peephole2 global_options.x_flag_peephole2
#endif
#ifdef GENERATOR_FILE
extern int flag_plan9_extensions;
#else
  int x_flag_plan9_extensions;
#define flag_plan9_extensions global_options.x_flag_plan9_extensions
#endif
#ifdef GENERATOR_FILE
extern int post_ipa_mem_report;
#else
  int x_post_ipa_mem_report;
#define post_ipa_mem_report global_options.x_post_ipa_mem_report
#endif
#ifdef GENERATOR_FILE
extern int pre_ipa_mem_report;
#else
  int x_pre_ipa_mem_report;
#define pre_ipa_mem_report global_options.x_pre_ipa_mem_report
#endif
#ifdef GENERATOR_FILE
extern int flag_predictive_commoning;
#else
  int x_flag_predictive_commoning;
#define flag_predictive_commoning global_options.x_flag_predictive_commoning
#endif
#ifdef GENERATOR_FILE
extern int flag_prefetch_loop_arrays;
#else
  int x_flag_prefetch_loop_arrays;
#define flag_prefetch_loop_arrays global_options.x_flag_prefetch_loop_arrays
#endif
#ifdef GENERATOR_FILE
extern int flag_pretty_templates;
#else
  int x_flag_pretty_templates;
#define flag_pretty_templates global_options.x_flag_pretty_templates
#endif
#ifdef GENERATOR_FILE
extern int profile_flag;
#else
  int x_profile_flag;
#define profile_flag global_options.x_profile_flag
#endif
#ifdef GENERATOR_FILE
extern int profile_arc_flag;
#else
  int x_profile_arc_flag;
#define profile_arc_flag global_options.x_profile_arc_flag
#endif
#ifdef GENERATOR_FILE
extern int flag_profile_correction;
#else
  int x_flag_profile_correction;
#define flag_profile_correction global_options.x_flag_profile_correction
#endif
#ifdef GENERATOR_FILE
extern const char *profile_data_prefix;
#else
  const char *x_profile_data_prefix;
#define profile_data_prefix global_options.x_profile_data_prefix
#endif
#ifdef GENERATOR_FILE
extern int flag_profile_use;
#else
  int x_flag_profile_use;
#define flag_profile_use global_options.x_flag_profile_use
#endif
#ifdef GENERATOR_FILE
extern int flag_profile_values;
#else
  int x_flag_profile_values;
#define flag_profile_values global_options.x_flag_profile_values
#endif
#ifdef GENERATOR_FILE
extern int flag_reciprocal_math;
#else
  int x_flag_reciprocal_math;
#define flag_reciprocal_math global_options.x_flag_reciprocal_math
#endif
#ifdef GENERATOR_FILE
extern int flag_record_gcc_switches;
#else
  int x_flag_record_gcc_switches;
#define flag_record_gcc_switches global_options.x_flag_record_gcc_switches
#endif
#ifdef GENERATOR_FILE
extern int flag_rename_registers;
#else
  int x_flag_rename_registers;
#define flag_rename_registers global_options.x_flag_rename_registers
#endif
#ifdef GENERATOR_FILE
extern int flag_reorder_blocks;
#else
  int x_flag_reorder_blocks;
#define flag_reorder_blocks global_options.x_flag_reorder_blocks
#endif
#ifdef GENERATOR_FILE
extern int flag_reorder_blocks_and_partition;
#else
  int x_flag_reorder_blocks_and_partition;
#define flag_reorder_blocks_and_partition global_options.x_flag_reorder_blocks_and_partition
#endif
#ifdef GENERATOR_FILE
extern int flag_reorder_functions;
#else
  int x_flag_reorder_functions;
#define flag_reorder_functions global_options.x_flag_reorder_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_replace_objc_classes;
#else
  int x_flag_replace_objc_classes;
#define flag_replace_objc_classes global_options.x_flag_replace_objc_classes
#endif
#ifdef GENERATOR_FILE
extern int flag_rerun_cse_after_loop;
#else
  int x_flag_rerun_cse_after_loop;
#define flag_rerun_cse_after_loop global_options.x_flag_rerun_cse_after_loop
#endif
#ifdef GENERATOR_FILE
extern int flag_resched_modulo_sched;
#else
  int x_flag_resched_modulo_sched;
#define flag_resched_modulo_sched global_options.x_flag_resched_modulo_sched
#endif
#ifdef GENERATOR_FILE
extern int flag_rounding_math;
#else
  int x_flag_rounding_math;
#define flag_rounding_math global_options.x_flag_rounding_math
#endif
#ifdef GENERATOR_FILE
extern int flag_rtti;
#else
  int x_flag_rtti;
#define flag_rtti global_options.x_flag_rtti
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_critical_path_heuristic;
#else
  int x_flag_sched_critical_path_heuristic;
#define flag_sched_critical_path_heuristic global_options.x_flag_sched_critical_path_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_dep_count_heuristic;
#else
  int x_flag_sched_dep_count_heuristic;
#define flag_sched_dep_count_heuristic global_options.x_flag_sched_dep_count_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_group_heuristic;
#else
  int x_flag_sched_group_heuristic;
#define flag_sched_group_heuristic global_options.x_flag_sched_group_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_interblock;
#else
  int x_flag_schedule_interblock;
#define flag_schedule_interblock global_options.x_flag_schedule_interblock
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_last_insn_heuristic;
#else
  int x_flag_sched_last_insn_heuristic;
#define flag_sched_last_insn_heuristic global_options.x_flag_sched_last_insn_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_pressure;
#else
  int x_flag_sched_pressure;
#define flag_sched_pressure global_options.x_flag_sched_pressure
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_rank_heuristic;
#else
  int x_flag_sched_rank_heuristic;
#define flag_sched_rank_heuristic global_options.x_flag_sched_rank_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_speculative;
#else
  int x_flag_schedule_speculative;
#define flag_schedule_speculative global_options.x_flag_schedule_speculative
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_spec_insn_heuristic;
#else
  int x_flag_sched_spec_insn_heuristic;
#define flag_sched_spec_insn_heuristic global_options.x_flag_sched_spec_insn_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_speculative_load;
#else
  int x_flag_schedule_speculative_load;
#define flag_schedule_speculative_load global_options.x_flag_schedule_speculative_load
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_speculative_load_dangerous;
#else
  int x_flag_schedule_speculative_load_dangerous;
#define flag_schedule_speculative_load_dangerous global_options.x_flag_schedule_speculative_load_dangerous
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_stalled_insns;
#else
  int x_flag_sched_stalled_insns;
#define flag_sched_stalled_insns global_options.x_flag_sched_stalled_insns
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_stalled_insns_dep;
#else
  int x_flag_sched_stalled_insns_dep;
#define flag_sched_stalled_insns_dep global_options.x_flag_sched_stalled_insns_dep
#endif
#ifdef GENERATOR_FILE
extern int sched_verbose_param;
#else
  int x_sched_verbose_param;
#define sched_verbose_param global_options.x_sched_verbose_param
#endif
#ifdef GENERATOR_FILE
extern int flag_sched2_use_superblocks;
#else
  int x_flag_sched2_use_superblocks;
#define flag_sched2_use_superblocks global_options.x_flag_sched2_use_superblocks
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_insns;
#else
  int x_flag_schedule_insns;
#define flag_schedule_insns global_options.x_flag_schedule_insns
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_insns_after_reload;
#else
  int x_flag_schedule_insns_after_reload;
#define flag_schedule_insns_after_reload global_options.x_flag_schedule_insns_after_reload
#endif
#ifdef GENERATOR_FILE
extern int flag_section_anchors;
#else
  int x_flag_section_anchors;
#define flag_section_anchors global_options.x_flag_section_anchors
#endif
#ifdef GENERATOR_FILE
extern int flag_sel_sched_pipelining;
#else
  int x_flag_sel_sched_pipelining;
#define flag_sel_sched_pipelining global_options.x_flag_sel_sched_pipelining
#endif
#ifdef GENERATOR_FILE
extern int flag_sel_sched_pipelining_outer_loops;
#else
  int x_flag_sel_sched_pipelining_outer_loops;
#define flag_sel_sched_pipelining_outer_loops global_options.x_flag_sel_sched_pipelining_outer_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_sel_sched_reschedule_pipelined;
#else
  int x_flag_sel_sched_reschedule_pipelined;
#define flag_sel_sched_reschedule_pipelined global_options.x_flag_sel_sched_reschedule_pipelined
#endif
#ifdef GENERATOR_FILE
extern int flag_selective_scheduling;
#else
  int x_flag_selective_scheduling;
#define flag_selective_scheduling global_options.x_flag_selective_scheduling
#endif
#ifdef GENERATOR_FILE
extern int flag_selective_scheduling2;
#else
  int x_flag_selective_scheduling2;
#define flag_selective_scheduling2 global_options.x_flag_selective_scheduling2
#endif
#ifdef GENERATOR_FILE
extern int flag_short_double;
#else
  int x_flag_short_double;
#define flag_short_double global_options.x_flag_short_double
#endif
#ifdef GENERATOR_FILE
extern int flag_short_enums;
#else
  int x_flag_short_enums;
#define flag_short_enums global_options.x_flag_short_enums
#endif
#ifdef GENERATOR_FILE
extern int flag_short_wchar;
#else
  int x_flag_short_wchar;
#define flag_short_wchar global_options.x_flag_short_wchar
#endif
#ifdef GENERATOR_FILE
extern int flag_show_column;
#else
  int x_flag_show_column;
#define flag_show_column global_options.x_flag_show_column
#endif
#ifdef GENERATOR_FILE
extern int flag_signaling_nans;
#else
  int x_flag_signaling_nans;
#define flag_signaling_nans global_options.x_flag_signaling_nans
#endif
#ifdef GENERATOR_FILE
extern int flag_signed_bitfields;
#else
  int x_flag_signed_bitfields;
#define flag_signed_bitfields global_options.x_flag_signed_bitfields
#endif
#ifdef GENERATOR_FILE
extern int flag_signed_char;
#else
  int x_flag_signed_char;
#define flag_signed_char global_options.x_flag_signed_char
#endif
#ifdef GENERATOR_FILE
extern int flag_signed_zeros;
#else
  int x_flag_signed_zeros;
#define flag_signed_zeros global_options.x_flag_signed_zeros
#endif
#ifdef GENERATOR_FILE
extern int flag_single_precision_constant;
#else
  int x_flag_single_precision_constant;
#define flag_single_precision_constant global_options.x_flag_single_precision_constant
#endif
#ifdef GENERATOR_FILE
extern int flag_split_ivs_in_unroller;
#else
  int x_flag_split_ivs_in_unroller;
#define flag_split_ivs_in_unroller global_options.x_flag_split_ivs_in_unroller
#endif
#ifdef GENERATOR_FILE
extern int flag_split_stack;
#else
  int x_flag_split_stack;
#define flag_split_stack global_options.x_flag_split_stack
#endif
#ifdef GENERATOR_FILE
extern int flag_split_wide_types;
#else
  int x_flag_split_wide_types;
#define flag_split_wide_types global_options.x_flag_split_wide_types
#endif
#ifdef GENERATOR_FILE
extern int flag_stack_protect;
#else
  int x_flag_stack_protect;
#define flag_stack_protect global_options.x_flag_stack_protect
#endif
#ifdef GENERATOR_FILE
extern int flag_stack_usage;
#else
  int x_flag_stack_usage;
#define flag_stack_usage global_options.x_flag_stack_usage
#endif
#ifdef GENERATOR_FILE
extern int flag_detailed_statistics;
#else
  int x_flag_detailed_statistics;
#define flag_detailed_statistics global_options.x_flag_detailed_statistics
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_aliasing;
#else
  int x_flag_strict_aliasing;
#define flag_strict_aliasing global_options.x_flag_strict_aliasing
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_enums;
#else
  int x_flag_strict_enums;
#define flag_strict_enums global_options.x_flag_strict_enums
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_overflow;
#else
  int x_flag_strict_overflow;
#define flag_strict_overflow global_options.x_flag_strict_overflow
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_volatile_bitfields;
#else
  int x_flag_strict_volatile_bitfields;
#define flag_strict_volatile_bitfields global_options.x_flag_strict_volatile_bitfields
#endif
#ifdef GENERATOR_FILE
extern int flag_syntax_only;
#else
  int x_flag_syntax_only;
#define flag_syntax_only global_options.x_flag_syntax_only
#endif
#ifdef GENERATOR_FILE
extern int flag_test_coverage;
#else
  int x_flag_test_coverage;
#define flag_test_coverage global_options.x_flag_test_coverage
#endif
#ifdef GENERATOR_FILE
extern int flag_thread_jumps;
#else
  int x_flag_thread_jumps;
#define flag_thread_jumps global_options.x_flag_thread_jumps
#endif
#ifdef GENERATOR_FILE
extern int flag_threadsafe_statics;
#else
  int x_flag_threadsafe_statics;
#define flag_threadsafe_statics global_options.x_flag_threadsafe_statics
#endif
#ifdef GENERATOR_FILE
extern int time_report;
#else
  int x_time_report;
#define time_report global_options.x_time_report
#endif
#ifdef GENERATOR_FILE
extern enum tls_model flag_tls_default;
#else
  enum tls_model x_flag_tls_default;
#define flag_tls_default global_options.x_flag_tls_default
#endif
#ifdef GENERATOR_FILE
extern int flag_toplevel_reorder;
#else
  int x_flag_toplevel_reorder;
#define flag_toplevel_reorder global_options.x_flag_toplevel_reorder
#endif
#ifdef GENERATOR_FILE
extern int flag_tracer;
#else
  int x_flag_tracer;
#define flag_tracer global_options.x_flag_tracer
#endif
#ifdef GENERATOR_FILE
extern int flag_trapping_math;
#else
  int x_flag_trapping_math;
#define flag_trapping_math global_options.x_flag_trapping_math
#endif
#ifdef GENERATOR_FILE
extern int flag_trapv;
#else
  int x_flag_trapv;
#define flag_trapv global_options.x_flag_trapv
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_bit_ccp;
#else
  int x_flag_tree_bit_ccp;
#define flag_tree_bit_ccp global_options.x_flag_tree_bit_ccp
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_builtin_call_dce;
#else
  int x_flag_tree_builtin_call_dce;
#define flag_tree_builtin_call_dce global_options.x_flag_tree_builtin_call_dce
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_ccp;
#else
  int x_flag_tree_ccp;
#define flag_tree_ccp global_options.x_flag_tree_ccp
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_ch;
#else
  int x_flag_tree_ch;
#define flag_tree_ch global_options.x_flag_tree_ch
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_copy_prop;
#else
  int x_flag_tree_copy_prop;
#define flag_tree_copy_prop global_options.x_flag_tree_copy_prop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_copyrename;
#else
  int x_flag_tree_copyrename;
#define flag_tree_copyrename global_options.x_flag_tree_copyrename
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_cselim;
#else
  int x_flag_tree_cselim;
#define flag_tree_cselim global_options.x_flag_tree_cselim
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_dce;
#else
  int x_flag_tree_dce;
#define flag_tree_dce global_options.x_flag_tree_dce
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_dom;
#else
  int x_flag_tree_dom;
#define flag_tree_dom global_options.x_flag_tree_dom
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_dse;
#else
  int x_flag_tree_dse;
#define flag_tree_dse global_options.x_flag_tree_dse
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_forwprop;
#else
  int x_flag_tree_forwprop;
#define flag_tree_forwprop global_options.x_flag_tree_forwprop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_fre;
#else
  int x_flag_tree_fre;
#define flag_tree_fre global_options.x_flag_tree_fre
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_distribute_patterns;
#else
  int x_flag_tree_loop_distribute_patterns;
#define flag_tree_loop_distribute_patterns global_options.x_flag_tree_loop_distribute_patterns
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_distribution;
#else
  int x_flag_tree_loop_distribution;
#define flag_tree_loop_distribution global_options.x_flag_tree_loop_distribution
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_if_convert;
#else
  int x_flag_tree_loop_if_convert;
#define flag_tree_loop_if_convert global_options.x_flag_tree_loop_if_convert
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_if_convert_stores;
#else
  int x_flag_tree_loop_if_convert_stores;
#define flag_tree_loop_if_convert_stores global_options.x_flag_tree_loop_if_convert_stores
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_im;
#else
  int x_flag_tree_loop_im;
#define flag_tree_loop_im global_options.x_flag_tree_loop_im
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_ivcanon;
#else
  int x_flag_tree_loop_ivcanon;
#define flag_tree_loop_ivcanon global_options.x_flag_tree_loop_ivcanon
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_optimize;
#else
  int x_flag_tree_loop_optimize;
#define flag_tree_loop_optimize global_options.x_flag_tree_loop_optimize
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_live_range_split;
#else
  int x_flag_tree_live_range_split;
#define flag_tree_live_range_split global_options.x_flag_tree_live_range_split
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_parallelize_loops;
#else
  int x_flag_tree_parallelize_loops;
#define flag_tree_parallelize_loops global_options.x_flag_tree_parallelize_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_phiprop;
#else
  int x_flag_tree_phiprop;
#define flag_tree_phiprop global_options.x_flag_tree_phiprop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_pre;
#else
  int x_flag_tree_pre;
#define flag_tree_pre global_options.x_flag_tree_pre
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_pta;
#else
  int x_flag_tree_pta;
#define flag_tree_pta global_options.x_flag_tree_pta
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_reassoc;
#else
  int x_flag_tree_reassoc;
#define flag_tree_reassoc global_options.x_flag_tree_reassoc
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_scev_cprop;
#else
  int x_flag_tree_scev_cprop;
#define flag_tree_scev_cprop global_options.x_flag_tree_scev_cprop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_sink;
#else
  int x_flag_tree_sink;
#define flag_tree_sink global_options.x_flag_tree_sink
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_slp_vectorize;
#else
  int x_flag_tree_slp_vectorize;
#define flag_tree_slp_vectorize global_options.x_flag_tree_slp_vectorize
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_sra;
#else
  int x_flag_tree_sra;
#define flag_tree_sra global_options.x_flag_tree_sra
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_switch_conversion;
#else
  int x_flag_tree_switch_conversion;
#define flag_tree_switch_conversion global_options.x_flag_tree_switch_conversion
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_ter;
#else
  int x_flag_tree_ter;
#define flag_tree_ter global_options.x_flag_tree_ter
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_vect_loop_version;
#else
  int x_flag_tree_vect_loop_version;
#define flag_tree_vect_loop_version global_options.x_flag_tree_vect_loop_version
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_vectorize;
#else
  int x_flag_tree_vectorize;
#define flag_tree_vectorize global_options.x_flag_tree_vectorize
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_vrp;
#else
  int x_flag_tree_vrp;
#define flag_tree_vrp global_options.x_flag_tree_vrp
#endif
#ifdef GENERATOR_FILE
extern int flag_unit_at_a_time;
#else
  int x_flag_unit_at_a_time;
#define flag_unit_at_a_time global_options.x_flag_unit_at_a_time
#endif
#ifdef GENERATOR_FILE
extern int flag_unroll_all_loops;
#else
  int x_flag_unroll_all_loops;
#define flag_unroll_all_loops global_options.x_flag_unroll_all_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_unroll_loops;
#else
  int x_flag_unroll_loops;
#define flag_unroll_loops global_options.x_flag_unroll_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_unsafe_loop_optimizations;
#else
  int x_flag_unsafe_loop_optimizations;
#define flag_unsafe_loop_optimizations global_options.x_flag_unsafe_loop_optimizations
#endif
#ifdef GENERATOR_FILE
extern int flag_unsafe_math_optimizations;
#else
  int x_flag_unsafe_math_optimizations;
#define flag_unsafe_math_optimizations global_options.x_flag_unsafe_math_optimizations
#endif
#ifdef GENERATOR_FILE
extern int flag_unswitch_loops;
#else
  int x_flag_unswitch_loops;
#define flag_unswitch_loops global_options.x_flag_unswitch_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_unwind_tables;
#else
  int x_flag_unwind_tables;
#define flag_unwind_tables global_options.x_flag_unwind_tables
#endif
#ifdef GENERATOR_FILE
extern int flag_use_cxa_atexit;
#else
  int x_flag_use_cxa_atexit;
#define flag_use_cxa_atexit global_options.x_flag_use_cxa_atexit
#endif
#ifdef GENERATOR_FILE
extern int flag_use_cxa_get_exception_ptr;
#else
  int x_flag_use_cxa_get_exception_ptr;
#define flag_use_cxa_get_exception_ptr global_options.x_flag_use_cxa_get_exception_ptr
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking;
#else
  int x_flag_var_tracking;
#define flag_var_tracking global_options.x_flag_var_tracking
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking_assignments;
#else
  int x_flag_var_tracking_assignments;
#define flag_var_tracking_assignments global_options.x_flag_var_tracking_assignments
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking_assignments_toggle;
#else
  int x_flag_var_tracking_assignments_toggle;
#define flag_var_tracking_assignments_toggle global_options.x_flag_var_tracking_assignments_toggle
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking_uninit;
#else
  int x_flag_var_tracking_uninit;
#define flag_var_tracking_uninit global_options.x_flag_var_tracking_uninit
#endif
#ifdef GENERATOR_FILE
extern int flag_variable_expansion_in_unroller;
#else
  int x_flag_variable_expansion_in_unroller;
#define flag_variable_expansion_in_unroller global_options.x_flag_variable_expansion_in_unroller
#endif
#ifdef GENERATOR_FILE
extern int flag_vect_cost_model;
#else
  int x_flag_vect_cost_model;
#define flag_vect_cost_model global_options.x_flag_vect_cost_model
#endif
#ifdef GENERATOR_FILE
extern int flag_verbose_asm;
#else
  int x_flag_verbose_asm;
#define flag_verbose_asm global_options.x_flag_verbose_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_visibility_ms_compat;
#else
  int x_flag_visibility_ms_compat;
#define flag_visibility_ms_compat global_options.x_flag_visibility_ms_compat
#endif
#ifdef GENERATOR_FILE
extern enum symbol_visibility default_visibility;
#else
  enum symbol_visibility x_default_visibility;
#define default_visibility global_options.x_default_visibility
#endif
#ifdef GENERATOR_FILE
extern int flag_value_profile_transformations;
#else
  int x_flag_value_profile_transformations;
#define flag_value_profile_transformations global_options.x_flag_value_profile_transformations
#endif
#ifdef GENERATOR_FILE
extern int flag_weak;
#else
  int x_flag_weak;
#define flag_weak global_options.x_flag_weak
#endif
#ifdef GENERATOR_FILE
extern int flag_web;
#else
  int x_flag_web;
#define flag_web global_options.x_flag_web
#endif
#ifdef GENERATOR_FILE
extern int flag_whole_program;
#else
  int x_flag_whole_program;
#define flag_whole_program global_options.x_flag_whole_program
#endif
#ifdef GENERATOR_FILE
extern int flag_working_directory;
#else
  int x_flag_working_directory;
#define flag_working_directory global_options.x_flag_working_directory
#endif
#ifdef GENERATOR_FILE
extern int flag_wpa;
#else
  int x_flag_wpa;
#define flag_wpa global_options.x_flag_wpa
#endif
#ifdef GENERATOR_FILE
extern int flag_wrapv;
#else
  int x_flag_wrapv;
#define flag_wrapv global_options.x_flag_wrapv
#endif
#ifdef GENERATOR_FILE
extern int flag_zee;
#else
  int x_flag_zee;
#define flag_zee global_options.x_flag_zee
#endif
#ifdef GENERATOR_FILE
extern int flag_zero_initialized_in_bss;
#else
  int x_flag_zero_initialized_in_bss;
#define flag_zero_initialized_in_bss global_options.x_flag_zero_initialized_in_bss
#endif
#ifdef GENERATOR_FILE
extern int flag_zero_link;
#else
  int x_flag_zero_link;
#define flag_zero_link global_options.x_flag_zero_link
#endif
#ifdef GENERATOR_FILE
extern int dwarf_version;
#else
  int x_dwarf_version;
#define dwarf_version global_options.x_dwarf_version
#endif
#ifdef GENERATOR_FILE
extern int flag_gen_declaration;
#else
  int x_flag_gen_declaration;
#define flag_gen_declaration global_options.x_flag_gen_declaration
#endif
#ifdef GENERATOR_FILE
extern int dwarf_strict;
#else
  int x_dwarf_strict;
#define dwarf_strict global_options.x_dwarf_strict
#endif
#ifdef GENERATOR_FILE
extern int flag_gtoggle;
#else
  int x_flag_gtoggle;
#define flag_gtoggle global_options.x_flag_gtoggle
#endif
#ifdef GENERATOR_FILE
extern const char *plugindir_string;
#else
  const char *x_plugindir_string;
#define plugindir_string global_options.x_plugindir_string
#endif
#ifdef GENERATOR_FILE
extern const char *msp430_opt_cpu;
#else
  const char *x_msp430_opt_cpu;
#define msp430_opt_cpu global_options.x_msp430_opt_cpu
#endif
#ifdef GENERATOR_FILE
extern int msp430_disable_watchdog;
#else
  int x_msp430_disable_watchdog;
#define msp430_disable_watchdog global_options.x_msp430_disable_watchdog
#endif
#ifdef GENERATOR_FILE
extern int msp430_enable_libcall_shift;
#else
  int x_msp430_enable_libcall_shift;
#define msp430_enable_libcall_shift global_options.x_msp430_enable_libcall_shift
#endif
#ifdef GENERATOR_FILE
extern const char *msp430_opt_ivcnt;
#else
  const char *x_msp430_opt_ivcnt;
#define msp430_opt_ivcnt global_options.x_msp430_opt_ivcnt
#endif
#ifdef GENERATOR_FILE
extern const char *msp430_mcu_name;
#else
  const char *x_msp430_mcu_name;
#define msp430_mcu_name global_options.x_msp430_mcu_name
#endif
#ifdef GENERATOR_FILE
extern const char *msp430_opt_mpy;
#else
  const char *x_msp430_opt_mpy;
#define msp430_opt_mpy global_options.x_msp430_opt_mpy
#endif
#ifdef GENERATOR_FILE
extern const char *asm_file_name;
#else
  const char *x_asm_file_name;
#define asm_file_name global_options.x_asm_file_name
#endif
#ifdef GENERATOR_FILE
extern int pass_exit_codes;
#else
  int x_pass_exit_codes;
#define pass_exit_codes global_options.x_pass_exit_codes
#endif
#ifdef GENERATOR_FILE
extern int pedantic;
#else
  int x_pedantic;
#define pedantic global_options.x_pedantic
#endif
#ifdef GENERATOR_FILE
extern int flag_pedantic_errors;
#else
  int x_flag_pedantic_errors;
#define flag_pedantic_errors global_options.x_flag_pedantic_errors
#endif
#ifdef GENERATOR_FILE
extern int use_pipes;
#else
  int x_use_pipes;
#define use_pipes global_options.x_use_pipes
#endif
#ifdef GENERATOR_FILE
extern const char *print_file_name;
#else
  const char *x_print_file_name;
#define print_file_name global_options.x_print_file_name
#endif
#ifdef GENERATOR_FILE
extern int print_multi_directory;
#else
  int x_print_multi_directory;
#define print_multi_directory global_options.x_print_multi_directory
#endif
#ifdef GENERATOR_FILE
extern int print_multi_lib;
#else
  int x_print_multi_lib;
#define print_multi_lib global_options.x_print_multi_lib
#endif
#ifdef GENERATOR_FILE
extern int print_multi_os_directory;
#else
  int x_print_multi_os_directory;
#define print_multi_os_directory global_options.x_print_multi_os_directory
#endif
#ifdef GENERATOR_FILE
extern const char *print_prog_name;
#else
  const char *x_print_prog_name;
#define print_prog_name global_options.x_print_prog_name
#endif
#ifdef GENERATOR_FILE
extern int print_search_dirs;
#else
  int x_print_search_dirs;
#define print_search_dirs global_options.x_print_search_dirs
#endif
#ifdef GENERATOR_FILE
extern int print_sysroot;
#else
  int x_print_sysroot;
#define print_sysroot global_options.x_print_sysroot
#endif
#ifdef GENERATOR_FILE
extern int print_sysroot_headers_suffix;
#else
  int x_print_sysroot_headers_suffix;
#define print_sysroot_headers_suffix global_options.x_print_sysroot_headers_suffix
#endif
#ifdef GENERATOR_FILE
extern int quiet_flag;
#else
  int x_quiet_flag;
#define quiet_flag global_options.x_quiet_flag
#endif
#ifdef GENERATOR_FILE
extern int report_times;
#else
  int x_report_times;
#define report_times global_options.x_report_times
#endif
#ifdef GENERATOR_FILE
extern int flag_undef;
#else
  int x_flag_undef;
#define flag_undef global_options.x_flag_undef
#endif
#ifdef GENERATOR_FILE
extern int verbose_flag;
#else
  int x_verbose_flag;
#define verbose_flag global_options.x_verbose_flag
#endif
#ifdef GENERATOR_FILE
extern int version_flag;
#else
  int x_version_flag;
#define version_flag global_options.x_version_flag
#endif
#ifdef GENERATOR_FILE
extern int inhibit_warnings;
#else
  int x_inhibit_warnings;
#define inhibit_warnings global_options.x_inhibit_warnings
#endif
#ifdef GENERATOR_FILE
extern const char *wrapper_string;
#else
  const char *x_wrapper_string;
#define wrapper_string global_options.x_wrapper_string
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_associative_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_cx_limited_range;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_finite_math_only;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_errno_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_reciprocal_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_rounding_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_signaling_nans;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_signed_zeros;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_trapping_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_unsafe_math_optimizations;
#endif
#ifndef GENERATOR_FILE
};
extern struct gcc_options global_options;
extern const struct gcc_options global_options_init;
extern struct gcc_options global_options_set;
#define target_flags_explicit global_options_set.x_target_flags
#endif
#endif

#if !defined(GCC_DRIVER) && !defined(IN_LIBGCC2) && !defined(IN_TARGET_LIBS)

/* Structure to save/restore optimization and target specific options.  */
struct GTY(()) cl_optimization
{
  int x_align_functions;
  int x_align_jumps;
  int x_align_labels;
  int x_align_loops;
  int x_flag_sched_stalled_insns;
  int x_flag_sched_stalled_insns_dep;
  enum fp_contract_mode x_flag_fp_contract_mode;
  unsigned char x_optimize;
  unsigned char x_optimize_size;
  signed char x_flag_asynchronous_unwind_tables;
  signed char x_flag_branch_on_count_reg;
  signed char x_flag_branch_probabilities;
  signed char x_flag_branch_target_load_optimize;
  signed char x_flag_branch_target_load_optimize2;
  signed char x_flag_btr_bb_exclusive;
  signed char x_flag_caller_saves;
  signed char x_flag_combine_stack_adjustments;
  signed char x_flag_no_common;
  signed char x_flag_compare_elim_after_reload;
  signed char x_flag_conserve_stack;
  signed char x_flag_cprop_registers;
  signed char x_flag_crossjumping;
  signed char x_flag_cse_follow_jumps;
  signed char x_flag_cx_fortran_rules;
  signed char x_flag_cx_limited_range;
  signed char x_flag_data_sections;
  signed char x_flag_dce;
  signed char x_flag_defer_pop;
  signed char x_flag_delayed_branch;
  signed char x_flag_delete_null_pointer_checks;
  signed char x_flag_devirtualize;
  signed char x_flag_dse;
  signed char x_flag_early_inlining;
  signed char x_flag_exceptions;
  signed char x_flag_expensive_optimizations;
  signed char x_flag_finite_math_only;
  signed char x_flag_float_store;
  signed char x_flag_forward_propagate;
  signed char x_flag_gcse;
  signed char x_flag_gcse_after_reload;
  signed char x_flag_gcse_las;
  signed char x_flag_gcse_lm;
  signed char x_flag_gcse_sm;
  signed char x_flag_graphite_identity;
  signed char x_flag_guess_branch_prob;
  signed char x_flag_if_conversion;
  signed char x_flag_if_conversion2;
  signed char x_flag_inline_functions;
  signed char x_flag_inline_functions_called_once;
  signed char x_flag_inline_small_functions;
  signed char x_flag_ipa_cp;
  signed char x_flag_ipa_cp_clone;
  signed char x_flag_ipa_matrix_reorg;
  signed char x_flag_ipa_profile;
  signed char x_flag_ipa_pta;
  signed char x_flag_ipa_pure_const;
  signed char x_flag_ipa_reference;
  signed char x_flag_ipa_sra;
  signed char x_flag_ivopts;
  signed char x_flag_jump_tables;
  signed char x_flag_loop_block;
  signed char x_flag_loop_flatten;
  signed char x_flag_loop_interchange;
  signed char x_flag_loop_parallelize_all;
  signed char x_flag_loop_strip_mine;
  signed char x_flag_lto_report;
  signed char x_flag_ltrans;
  signed char x_flag_errno_math;
  signed char x_flag_merge_constants;
  signed char x_flag_modulo_sched;
  signed char x_flag_move_loop_invariants;
  signed char x_flag_non_call_exceptions;
  signed char x_flag_nothrow_opt;
  signed char x_flag_omit_frame_pointer;
  signed char x_flag_regmove;
  signed char x_flag_optimize_sibling_calls;
  signed char x_flag_pack_struct;
  signed char x_flag_peel_loops;
  signed char x_flag_no_peephole;
  signed char x_flag_peephole2;
  signed char x_flag_predictive_commoning;
  signed char x_flag_prefetch_loop_arrays;
  signed char x_flag_pcc_struct_return;
  signed char x_flag_rename_registers;
  signed char x_flag_reorder_blocks;
  signed char x_flag_reorder_blocks_and_partition;
  signed char x_flag_reorder_functions;
  signed char x_flag_rerun_cse_after_loop;
  signed char x_flag_resched_modulo_sched;
  signed char x_flag_rounding_math;
  signed char x_flag_rtti;
  signed char x_flag_sched_critical_path_heuristic;
  signed char x_flag_sched_dep_count_heuristic;
  signed char x_flag_sched_group_heuristic;
  signed char x_flag_schedule_interblock;
  signed char x_flag_sched_last_insn_heuristic;
  signed char x_flag_sched_pressure;
  signed char x_flag_sched_rank_heuristic;
  signed char x_flag_schedule_speculative;
  signed char x_flag_sched_spec_insn_heuristic;
  signed char x_flag_schedule_speculative_load;
  signed char x_flag_schedule_speculative_load_dangerous;
  signed char x_flag_sched2_use_superblocks;
  signed char x_flag_schedule_insns;
  signed char x_flag_schedule_insns_after_reload;
  signed char x_flag_section_anchors;
  signed char x_flag_sel_sched_pipelining;
  signed char x_flag_sel_sched_pipelining_outer_loops;
  signed char x_flag_sel_sched_reschedule_pipelined;
  signed char x_flag_selective_scheduling;
  signed char x_flag_selective_scheduling2;
  signed char x_flag_short_double;
  signed char x_flag_short_enums;
  signed char x_flag_short_wchar;
  signed char x_flag_signaling_nans;
  signed char x_flag_signed_zeros;
  signed char x_flag_single_precision_constant;
  signed char x_flag_split_ivs_in_unroller;
  signed char x_flag_split_wide_types;
  signed char x_flag_strict_aliasing;
  signed char x_flag_strict_enums;
  signed char x_flag_thread_jumps;
  signed char x_flag_threadsafe_statics;
  signed char x_flag_toplevel_reorder;
  signed char x_flag_trapping_math;
  signed char x_flag_trapv;
  signed char x_flag_tree_bit_ccp;
  signed char x_flag_tree_builtin_call_dce;
  signed char x_flag_tree_ccp;
  signed char x_flag_tree_ch;
  signed char x_flag_tree_copy_prop;
  signed char x_flag_tree_copyrename;
  signed char x_flag_tree_cselim;
  signed char x_flag_tree_dce;
  signed char x_flag_tree_dom;
  signed char x_flag_tree_dse;
  signed char x_flag_tree_forwprop;
  signed char x_flag_tree_fre;
  signed char x_flag_tree_loop_distribute_patterns;
  signed char x_flag_tree_loop_distribution;
  signed char x_flag_tree_loop_if_convert;
  signed char x_flag_tree_loop_if_convert_stores;
  signed char x_flag_tree_loop_im;
  signed char x_flag_tree_loop_ivcanon;
  signed char x_flag_tree_loop_optimize;
  signed char x_flag_tree_live_range_split;
  signed char x_flag_tree_phiprop;
  signed char x_flag_tree_pre;
  signed char x_flag_tree_pta;
  signed char x_flag_tree_reassoc;
  signed char x_flag_tree_scev_cprop;
  signed char x_flag_tree_sink;
  signed char x_flag_tree_slp_vectorize;
  signed char x_flag_tree_sra;
  signed char x_flag_tree_switch_conversion;
  signed char x_flag_tree_ter;
  signed char x_flag_tree_vect_loop_version;
  signed char x_flag_tree_vectorize;
  signed char x_flag_tree_vrp;
  signed char x_flag_unit_at_a_time;
  signed char x_flag_unroll_all_loops;
  signed char x_flag_unroll_loops;
  signed char x_flag_unsafe_loop_optimizations;
  signed char x_flag_unsafe_math_optimizations;
  signed char x_flag_unswitch_loops;
  signed char x_flag_unwind_tables;
  signed char x_flag_var_tracking;
  signed char x_flag_var_tracking_assignments;
  signed char x_flag_var_tracking_assignments_toggle;
  signed char x_flag_var_tracking_uninit;
  signed char x_flag_variable_expansion_in_unroller;
  signed char x_flag_vect_cost_model;
  signed char x_flag_value_profile_transformations;
  signed char x_flag_web;
  signed char x_flag_whole_program;
  signed char x_flag_wpa;
  signed char x_flag_wrapv;
};

/* Structure to save/restore selected target specific options.  */
struct GTY(()) cl_target_option
{
  int x_target_flags;
};


/* Save optimization variables into a structure.  */
extern void cl_optimization_save (struct cl_optimization *, struct gcc_options *);

/* Restore optimization variables from a structure.  */
extern void cl_optimization_restore (struct gcc_options *, struct cl_optimization *);

/* Print optimization variables from a structure.  */
extern void cl_optimization_print (FILE *, int, struct cl_optimization *);

/* Save selected option variables into a structure.  */
extern void cl_target_option_save (struct cl_target_option *, struct gcc_options *);

/* Restore selected option variables from a structure.  */
extern void cl_target_option_restore (struct gcc_options *, struct cl_target_option *);

/* Print target option variables from a structure.  */
extern void cl_target_option_print (FILE *, int, struct cl_target_option *);
#endif

#define MASK_NO_HWMUL (1 << 0)
#define MASK_INLINESIHWMUL (1 << 1)
#define MASK_NVWA (1 << 2)
#define MASK_NOINT_HWMUL (1 << 3)
#define MASK_SAVE_PROLOGUE (1 << 4)

#define TARGET_NO_HWMUL ((target_flags & MASK_NO_HWMUL) != 0)
#define TARGET_INLINESIHWMUL ((target_flags & MASK_INLINESIHWMUL) != 0)
#define TARGET_NVWA ((target_flags & MASK_NVWA) != 0)
#define TARGET_NOINT_HWMUL ((target_flags & MASK_NOINT_HWMUL) != 0)
#define TARGET_SAVE_PROLOGUE ((target_flags & MASK_SAVE_PROLOGUE) != 0)


#define CL_C          (1 << 0)
#define CL_CXX        (1 << 1)
#define CL_LTO        (1 << 2)
#define CL_ObjC       (1 << 3)
#define CL_ObjCXX     (1 << 4)
#define CL_LANG_ALL   ((1 << 5) - 1)

enum opt_code
{
  OPT____ = 0,                               /* -### */
  /* OPT__all_warnings = 1, */               /* --all-warnings */
  /* OPT__ansi = 2, */                       /* --ansi */
  /* OPT__assemble = 3, */                   /* --assemble */
  /* OPT__assert = 4, */                     /* --assert */
  /* OPT__assert_ = 5, */                    /* --assert= */
  /* OPT__comments = 6, */                   /* --comments */
  /* OPT__comments_in_macros = 7, */         /* --comments-in-macros */
  /* OPT__compile = 8, */                    /* --compile */
  /* OPT__coverage = 9, */                   /* --coverage */
  /* OPT__debug = 10, */                     /* --debug */
  /* OPT__define_macro = 11, */              /* --define-macro */
  /* OPT__define_macro_ = 12, */             /* --define-macro= */
  /* OPT__dependencies = 13, */              /* --dependencies */
  /* OPT__dump = 14, */                      /* --dump */
  /* OPT__dump_ = 15, */                     /* --dump= */
  /* OPT__dumpbase = 16, */                  /* --dumpbase */
  /* OPT__dumpdir = 17, */                   /* --dumpdir */
  /* OPT__entry = 18, */                     /* --entry */
  /* OPT__entry_ = 19, */                    /* --entry= */
  /* OPT__extra_warnings = 20, */            /* --extra-warnings */
  /* OPT__for_assembler = 21, */             /* --for-assembler */
  /* OPT__for_assembler_ = 22, */            /* --for-assembler= */
  /* OPT__for_linker = 23, */                /* --for-linker */
  /* OPT__for_linker_ = 24, */               /* --for-linker= */
  /* OPT__force_link = 25, */                /* --force-link */
  /* OPT__force_link_ = 26, */               /* --force-link= */
  OPT__help = 27,                            /* --help */
  OPT__help_ = 28,                           /* --help= */
  /* OPT__imacros = 29, */                   /* --imacros */
  /* OPT__imacros_ = 30, */                  /* --imacros= */
  /* OPT__include = 31, */                   /* --include */
  /* OPT__include_barrier = 32, */           /* --include-barrier */
  /* OPT__include_directory = 33, */         /* --include-directory */
  /* OPT__include_directory_after = 34, */   /* --include-directory-after */
  /* OPT__include_directory_after_ = 35, */  /* --include-directory-after= */
  /* OPT__include_directory_ = 36, */        /* --include-directory= */
  /* OPT__include_prefix = 37, */            /* --include-prefix */
  /* OPT__include_prefix_ = 38, */           /* --include-prefix= */
  /* OPT__include_with_prefix = 39, */       /* --include-with-prefix */
  /* OPT__include_with_prefix_after = 40, */ /* --include-with-prefix-after */
  /* OPT__include_with_prefix_after_ = 41, *//* --include-with-prefix-after= */
  /* OPT__include_with_prefix_before = 42, *//* --include-with-prefix-before */
  /* OPT__include_with_prefix_before_ = 43, *//* --include-with-prefix-before= */
  /* OPT__include_with_prefix_ = 44, */      /* --include-with-prefix= */
  /* OPT__include_ = 45, */                  /* --include= */
  /* OPT__language = 46, */                  /* --language */
  /* OPT__language_ = 47, */                 /* --language= */
  /* OPT__library_directory = 48, */         /* --library-directory */
  /* OPT__library_directory_ = 49, */        /* --library-directory= */
  /* OPT__no_canonical_prefixes = 50, */     /* --no-canonical-prefixes */
  /* OPT__no_integrated_cpp = 51, */         /* --no-integrated-cpp */
  /* OPT__no_line_commands = 52, */          /* --no-line-commands */
  /* OPT__no_standard_includes = 53, */      /* --no-standard-includes */
  /* OPT__no_standard_libraries = 54, */     /* --no-standard-libraries */
  /* OPT__no_warnings = 55, */               /* --no-warnings */
  /* OPT__optimize = 56, */                  /* --optimize */
  /* OPT__output = 57, */                    /* --output */
  OPT__output_pch_ = 58,                     /* --output-pch= */
  /* OPT__output_ = 59, */                   /* --output= */
  OPT__param = 60,                           /* --param */
  /* OPT__param_ = 61, */                    /* --param= */
  /* OPT__pass_exit_codes = 62, */           /* --pass-exit-codes */
  /* OPT__pedantic = 63, */                  /* --pedantic */
  /* OPT__pedantic_errors = 64, */           /* --pedantic-errors */
  /* OPT__pie = 65, */                       /* --pie */
  /* OPT__pipe = 66, */                      /* --pipe */
  /* OPT__prefix = 67, */                    /* --prefix */
  /* OPT__prefix_ = 68, */                   /* --prefix= */
  /* OPT__preprocess = 69, */                /* --preprocess */
  /* OPT__print_file_name = 70, */           /* --print-file-name */
  /* OPT__print_file_name_ = 71, */          /* --print-file-name= */
  /* OPT__print_libgcc_file_name = 72, */    /* --print-libgcc-file-name */
  /* OPT__print_missing_file_dependencies = 73, *//* --print-missing-file-dependencies */
  /* OPT__print_multi_directory = 74, */     /* --print-multi-directory */
  /* OPT__print_multi_lib = 75, */           /* --print-multi-lib */
  /* OPT__print_multi_os_directory = 76, */  /* --print-multi-os-directory */
  /* OPT__print_prog_name = 77, */           /* --print-prog-name */
  /* OPT__print_prog_name_ = 78, */          /* --print-prog-name= */
  /* OPT__print_search_dirs = 79, */         /* --print-search-dirs */
  /* OPT__print_sysroot = 80, */             /* --print-sysroot */
  /* OPT__print_sysroot_headers_suffix = 81, *//* --print-sysroot-headers-suffix */
  /* OPT__profile = 82, */                   /* --profile */
  /* OPT__save_temps = 83, */                /* --save-temps */
  /* OPT__shared = 84, */                    /* --shared */
  /* OPT__specs = 85, */                     /* --specs */
  /* OPT__specs_ = 86, */                    /* --specs= */
  /* OPT__static = 87, */                    /* --static */
  /* OPT__symbolic = 88, */                  /* --symbolic */
  /* OPT__sysroot = 89, */                   /* --sysroot */
  OPT__sysroot_ = 90,                        /* --sysroot= */
  OPT__target_help = 91,                     /* --target-help */
  /* OPT__time = 92, */                      /* --time */
  /* OPT__trace_includes = 93, */            /* --trace-includes */
  /* OPT__traditional = 94, */               /* --traditional */
  /* OPT__traditional_cpp = 95, */           /* --traditional-cpp */
  /* OPT__trigraphs = 96, */                 /* --trigraphs */
  /* OPT__undefine_macro = 97, */            /* --undefine-macro */
  /* OPT__undefine_macro_ = 98, */           /* --undefine-macro= */
  /* OPT__user_dependencies = 99, */         /* --user-dependencies */
  /* OPT__verbose = 100, */                  /* --verbose */
  OPT__version = 101,                        /* --version */
  /* OPT__write_dependencies = 102, */       /* --write-dependencies */
  /* OPT__write_user_dependencies = 103, */  /* --write-user-dependencies */
  OPT_A = 104,                               /* -A */
  OPT_B = 105,                               /* -B */
  OPT_C = 106,                               /* -C */
  OPT_CC = 107,                              /* -CC */
  OPT_D = 108,                               /* -D */
  OPT_E = 109,                               /* -E */
  OPT_F = 110,                               /* -F */
  OPT_H = 111,                               /* -H */
  OPT_I = 112,                               /* -I */
  OPT_L = 113,                               /* -L */
  OPT_M = 114,                               /* -M */
  OPT_MD = 115,                              /* -MD */
  OPT_MF = 116,                              /* -MF */
  OPT_MG = 117,                              /* -MG */
  OPT_MM = 118,                              /* -MM */
  OPT_MMD = 119,                             /* -MMD */
  OPT_MP = 120,                              /* -MP */
  OPT_MQ = 121,                              /* -MQ */
  OPT_MT = 122,                              /* -MT */
  OPT_N = 123,                               /* -N */
  OPT_O = 124,                               /* -O */
  OPT_Ofast = 125,                           /* -Ofast */
  OPT_Os = 126,                              /* -Os */
  OPT_P = 127,                               /* -P */
  OPT_Q = 128,                               /* -Q */
  OPT_Qn = 129,                              /* -Qn */
  OPT_Qy = 130,                              /* -Qy */
  OPT_R = 131,                               /* -R */
  OPT_S = 132,                               /* -S */
  OPT_T = 133,                               /* -T */
  OPT_Tbss = 134,                            /* -Tbss */
  OPT_Tbss_ = 135,                           /* -Tbss= */
  OPT_Tdata = 136,                           /* -Tdata */
  OPT_Tdata_ = 137,                          /* -Tdata= */
  OPT_Ttext = 138,                           /* -Ttext */
  OPT_Ttext_ = 139,                          /* -Ttext= */
  OPT_U = 140,                               /* -U */
  /* OPT_W = 141, */                         /* -W */
  OPT_Wa_ = 142,                             /* -Wa, */
  OPT_Wabi = 143,                            /* -Wabi */
  OPT_Waddress = 144,                        /* -Waddress */
  OPT_Waggregate_return = 145,               /* -Waggregate-return */
  OPT_Wall = 146,                            /* -Wall */
  OPT_Warray_bounds = 147,                   /* -Warray-bounds */
  OPT_Wassign_intercept = 148,               /* -Wassign-intercept */
  OPT_Wattributes = 149,                     /* -Wattributes */
  OPT_Wbad_function_cast = 150,              /* -Wbad-function-cast */
  OPT_Wbuiltin_macro_redefined = 151,        /* -Wbuiltin-macro-redefined */
  OPT_Wc___compat = 152,                     /* -Wc++-compat */
  OPT_Wc__0x_compat = 153,                   /* -Wc++0x-compat */
  OPT_Wcast_align = 154,                     /* -Wcast-align */
  OPT_Wcast_qual = 155,                      /* -Wcast-qual */
  OPT_Wchar_subscripts = 156,                /* -Wchar-subscripts */
  OPT_Wclobbered = 157,                      /* -Wclobbered */
  OPT_Wcomment = 158,                        /* -Wcomment */
  /* OPT_Wcomments = 159, */                 /* -Wcomments */
  OPT_Wconversion = 160,                     /* -Wconversion */
  OPT_Wconversion_null = 161,                /* -Wconversion-null */
  OPT_Wcoverage_mismatch = 162,              /* -Wcoverage-mismatch */
  OPT_Wcpp = 163,                            /* -Wcpp */
  OPT_Wctor_dtor_privacy = 164,              /* -Wctor-dtor-privacy */
  OPT_Wdeclaration_after_statement = 165,    /* -Wdeclaration-after-statement */
  OPT_Wdeprecated = 166,                     /* -Wdeprecated */
  OPT_Wdeprecated_declarations = 167,        /* -Wdeprecated-declarations */
  OPT_Wdisabled_optimization = 168,          /* -Wdisabled-optimization */
  OPT_Wdiv_by_zero = 169,                    /* -Wdiv-by-zero */
  OPT_Wdouble_promotion = 170,               /* -Wdouble-promotion */
  OPT_Weffc__ = 171,                         /* -Weffc++ */
  OPT_Wempty_body = 172,                     /* -Wempty-body */
  OPT_Wendif_labels = 173,                   /* -Wendif-labels */
  OPT_Wenum_compare = 174,                   /* -Wenum-compare */
  OPT_Werror = 175,                          /* -Werror */
  /* OPT_Werror_implicit_function_declaration = 176, *//* -Werror-implicit-function-declaration */
  OPT_Werror_ = 177,                         /* -Werror= */
  OPT_Wextra = 178,                          /* -Wextra */
  OPT_Wfatal_errors = 179,                   /* -Wfatal-errors */
  OPT_Wfloat_equal = 180,                    /* -Wfloat-equal */
  OPT_Wformat = 181,                         /* -Wformat */
  OPT_Wformat_contains_nul = 182,            /* -Wformat-contains-nul */
  OPT_Wformat_extra_args = 183,              /* -Wformat-extra-args */
  OPT_Wformat_nonliteral = 184,              /* -Wformat-nonliteral */
  OPT_Wformat_security = 185,                /* -Wformat-security */
  OPT_Wformat_y2k = 186,                     /* -Wformat-y2k */
  OPT_Wformat_zero_length = 187,             /* -Wformat-zero-length */
  OPT_Wformat_ = 188,                        /* -Wformat= */
  OPT_Wframe_larger_than_ = 189,             /* -Wframe-larger-than= */
  OPT_Wignored_qualifiers = 190,             /* -Wignored-qualifiers */
  OPT_Wimplicit = 191,                       /* -Wimplicit */
  OPT_Wimplicit_function_declaration = 192,  /* -Wimplicit-function-declaration */
  OPT_Wimplicit_int = 193,                   /* -Wimplicit-int */
  /* OPT_Wimport = 194, */                   /* -Wimport */
  OPT_Winit_self = 195,                      /* -Winit-self */
  OPT_Winline = 196,                         /* -Winline */
  OPT_Wint_to_pointer_cast = 197,            /* -Wint-to-pointer-cast */
  OPT_Winvalid_offsetof = 198,               /* -Winvalid-offsetof */
  OPT_Winvalid_pch = 199,                    /* -Winvalid-pch */
  OPT_Wjump_misses_init = 200,               /* -Wjump-misses-init */
  OPT_Wl_ = 201,                             /* -Wl, */
  /* OPT_Wlarger_than_ = 202, */             /* -Wlarger-than- */
  OPT_Wlarger_than_ = 203,                   /* -Wlarger-than= */
  OPT_Wlogical_op = 204,                     /* -Wlogical-op */
  OPT_Wlong_long = 205,                      /* -Wlong-long */
  OPT_Wmain = 206,                           /* -Wmain */
  OPT_Wmissing_braces = 207,                 /* -Wmissing-braces */
  OPT_Wmissing_declarations = 208,           /* -Wmissing-declarations */
  OPT_Wmissing_field_initializers = 209,     /* -Wmissing-field-initializers */
  OPT_Wmissing_format_attribute = 210,       /* -Wmissing-format-attribute */
  OPT_Wmissing_include_dirs = 211,           /* -Wmissing-include-dirs */
  OPT_Wmissing_noreturn = 212,               /* -Wmissing-noreturn */
  OPT_Wmissing_parameter_type = 213,         /* -Wmissing-parameter-type */
  OPT_Wmissing_prototypes = 214,             /* -Wmissing-prototypes */
  OPT_Wmudflap = 215,                        /* -Wmudflap */
  OPT_Wmultichar = 216,                      /* -Wmultichar */
  OPT_Wnested_externs = 217,                 /* -Wnested-externs */
  OPT_Wnoexcept = 218,                       /* -Wnoexcept */
  OPT_Wnon_template_friend = 219,            /* -Wnon-template-friend */
  OPT_Wnon_virtual_dtor = 220,               /* -Wnon-virtual-dtor */
  OPT_Wnonnull = 221,                        /* -Wnonnull */
  OPT_Wnormalized_ = 222,                    /* -Wnormalized= */
  OPT_Wold_style_cast = 223,                 /* -Wold-style-cast */
  OPT_Wold_style_declaration = 224,          /* -Wold-style-declaration */
  OPT_Wold_style_definition = 225,           /* -Wold-style-definition */
  OPT_Woverflow = 226,                       /* -Woverflow */
  OPT_Woverlength_strings = 227,             /* -Woverlength-strings */
  OPT_Woverloaded_virtual = 228,             /* -Woverloaded-virtual */
  OPT_Woverride_init = 229,                  /* -Woverride-init */
  OPT_Wp_ = 230,                             /* -Wp, */
  OPT_Wpacked = 231,                         /* -Wpacked */
  OPT_Wpacked_bitfield_compat = 232,         /* -Wpacked-bitfield-compat */
  OPT_Wpadded = 233,                         /* -Wpadded */
  OPT_Wparentheses = 234,                    /* -Wparentheses */
  OPT_Wpmf_conversions = 235,                /* -Wpmf-conversions */
  OPT_Wpointer_arith = 236,                  /* -Wpointer-arith */
  OPT_Wpointer_sign = 237,                   /* -Wpointer-sign */
  OPT_Wpointer_to_int_cast = 238,            /* -Wpointer-to-int-cast */
  OPT_Wpragmas = 239,                        /* -Wpragmas */
  OPT_Wproperty_assign_default = 240,        /* -Wproperty-assign-default */
  OPT_Wprotocol = 241,                       /* -Wprotocol */
  OPT_Wpsabi = 242,                          /* -Wpsabi */
  OPT_Wredundant_decls = 243,                /* -Wredundant-decls */
  OPT_Wreorder = 244,                        /* -Wreorder */
  OPT_Wreturn_type = 245,                    /* -Wreturn-type */
  OPT_Wselector = 246,                       /* -Wselector */
  OPT_Wsequence_point = 247,                 /* -Wsequence-point */
  OPT_Wshadow = 248,                         /* -Wshadow */
  OPT_Wsign_compare = 249,                   /* -Wsign-compare */
  OPT_Wsign_conversion = 250,                /* -Wsign-conversion */
  OPT_Wsign_promo = 251,                     /* -Wsign-promo */
  OPT_Wstack_protector = 252,                /* -Wstack-protector */
  OPT_Wstrict_aliasing = 253,                /* -Wstrict-aliasing */
  OPT_Wstrict_aliasing_ = 254,               /* -Wstrict-aliasing= */
  OPT_Wstrict_null_sentinel = 255,           /* -Wstrict-null-sentinel */
  OPT_Wstrict_overflow = 256,                /* -Wstrict-overflow */
  OPT_Wstrict_overflow_ = 257,               /* -Wstrict-overflow= */
  OPT_Wstrict_prototypes = 258,              /* -Wstrict-prototypes */
  OPT_Wstrict_selector_match = 259,          /* -Wstrict-selector-match */
  OPT_Wsuggest_attribute_const = 260,        /* -Wsuggest-attribute=const */
  OPT_Wsuggest_attribute_noreturn = 261,     /* -Wsuggest-attribute=noreturn */
  OPT_Wsuggest_attribute_pure = 262,         /* -Wsuggest-attribute=pure */
  OPT_Wswitch = 263,                         /* -Wswitch */
  OPT_Wswitch_default = 264,                 /* -Wswitch-default */
  OPT_Wswitch_enum = 265,                    /* -Wswitch-enum */
  OPT_Wsync_nand = 266,                      /* -Wsync-nand */
  OPT_Wsynth = 267,                          /* -Wsynth */
  OPT_Wsystem_headers = 268,                 /* -Wsystem-headers */
  OPT_Wtraditional = 269,                    /* -Wtraditional */
  OPT_Wtraditional_conversion = 270,         /* -Wtraditional-conversion */
  OPT_Wtrampolines = 271,                    /* -Wtrampolines */
  OPT_Wtrigraphs = 272,                      /* -Wtrigraphs */
  OPT_Wtype_limits = 273,                    /* -Wtype-limits */
  OPT_Wundeclared_selector = 274,            /* -Wundeclared-selector */
  OPT_Wundef = 275,                          /* -Wundef */
  OPT_Wuninitialized = 276,                  /* -Wuninitialized */
  OPT_Wunknown_pragmas = 277,                /* -Wunknown-pragmas */
  /* OPT_Wunreachable_code = 278, */         /* -Wunreachable-code */
  OPT_Wunsafe_loop_optimizations = 279,      /* -Wunsafe-loop-optimizations */
  OPT_Wunsuffixed_float_constants = 280,     /* -Wunsuffixed-float-constants */
  OPT_Wunused = 281,                         /* -Wunused */
  OPT_Wunused_but_set_parameter = 282,       /* -Wunused-but-set-parameter */
  OPT_Wunused_but_set_variable = 283,        /* -Wunused-but-set-variable */
  OPT_Wunused_function = 284,                /* -Wunused-function */
  OPT_Wunused_label = 285,                   /* -Wunused-label */
  OPT_Wunused_macros = 286,                  /* -Wunused-macros */
  OPT_Wunused_parameter = 287,               /* -Wunused-parameter */
  OPT_Wunused_result = 288,                  /* -Wunused-result */
  OPT_Wunused_value = 289,                   /* -Wunused-value */
  OPT_Wunused_variable = 290,                /* -Wunused-variable */
  OPT_Wvariadic_macros = 291,                /* -Wvariadic-macros */
  OPT_Wvla = 292,                            /* -Wvla */
  OPT_Wvolatile_register_var = 293,          /* -Wvolatile-register-var */
  OPT_Wwrite_strings = 294,                  /* -Wwrite-strings */
  OPT_Xassembler = 295,                      /* -Xassembler */
  OPT_Xlinker = 296,                         /* -Xlinker */
  OPT_Xpreprocessor = 297,                   /* -Xpreprocessor */
  OPT_Z = 298,                               /* -Z */
  OPT_ansi = 299,                            /* -ansi */
  OPT_aux_info = 300,                        /* -aux-info */
  /* OPT_aux_info_ = 301, */                 /* -aux-info= */
  OPT_auxbase = 302,                         /* -auxbase */
  OPT_auxbase_strip = 303,                   /* -auxbase-strip */
  OPT_c = 304,                               /* -c */
  OPT_coverage = 305,                        /* -coverage */
  OPT_d = 306,                               /* -d */
  OPT_dumpbase = 307,                        /* -dumpbase */
  OPT_dumpdir = 308,                         /* -dumpdir */
  OPT_dumpmachine = 309,                     /* -dumpmachine */
  OPT_dumpspecs = 310,                       /* -dumpspecs */
  OPT_dumpversion = 311,                     /* -dumpversion */
  OPT_e = 312,                               /* -e */
  OPT_export_dynamic = 313,                  /* -export-dynamic */
  OPT_fPIC = 314,                            /* -fPIC */
  OPT_fPIE = 315,                            /* -fPIE */
  OPT_fabi_version_ = 316,                   /* -fabi-version= */
  OPT_faccess_control = 317,                 /* -faccess-control */
  OPT_falign_functions = 318,                /* -falign-functions */
  OPT_falign_functions_ = 319,               /* -falign-functions= */
  OPT_falign_jumps = 320,                    /* -falign-jumps */
  OPT_falign_jumps_ = 321,                   /* -falign-jumps= */
  OPT_falign_labels = 322,                   /* -falign-labels */
  OPT_falign_labels_ = 323,                  /* -falign-labels= */
  OPT_falign_loops = 324,                    /* -falign-loops */
  OPT_falign_loops_ = 325,                   /* -falign-loops= */
  /* OPT_fall_virtual = 326, */              /* -fall-virtual */
  /* OPT_falt_external_templates = 327, */   /* -falt-external-templates */
  /* OPT_fargument_alias = 328, */           /* -fargument-alias */
  /* OPT_fargument_noalias = 329, */         /* -fargument-noalias */
  /* OPT_fargument_noalias_anything = 330, *//* -fargument-noalias-anything */
  /* OPT_fargument_noalias_global = 331, */  /* -fargument-noalias-global */
  OPT_fasm = 332,                            /* -fasm */
  OPT_fassociative_math = 333,               /* -fassociative-math */
  OPT_fasynchronous_unwind_tables = 334,     /* -fasynchronous-unwind-tables */
  OPT_fauto_inc_dec = 335,                   /* -fauto-inc-dec */
  OPT_fbounds_check = 336,                   /* -fbounds-check */
  OPT_fbranch_count_reg = 337,               /* -fbranch-count-reg */
  OPT_fbranch_probabilities = 338,           /* -fbranch-probabilities */
  OPT_fbranch_target_load_optimize = 339,    /* -fbranch-target-load-optimize */
  OPT_fbranch_target_load_optimize2 = 340,   /* -fbranch-target-load-optimize2 */
  OPT_fbtr_bb_exclusive = 341,               /* -fbtr-bb-exclusive */
  OPT_fbuiltin = 342,                        /* -fbuiltin */
  OPT_fbuiltin_ = 343,                       /* -fbuiltin- */
  OPT_fcall_saved_ = 344,                    /* -fcall-saved- */
  OPT_fcall_used_ = 345,                     /* -fcall-used- */
  OPT_fcaller_saves = 346,                   /* -fcaller-saves */
  OPT_fcheck_data_deps = 347,                /* -fcheck-data-deps */
  OPT_fcheck_new = 348,                      /* -fcheck-new */
  OPT_fcombine_stack_adjustments = 349,      /* -fcombine-stack-adjustments */
  OPT_fcommon = 350,                         /* -fcommon */
  OPT_fcompare_debug = 351,                  /* -fcompare-debug */
  OPT_fcompare_debug_second = 352,           /* -fcompare-debug-second */
  OPT_fcompare_debug_ = 353,                 /* -fcompare-debug= */
  OPT_fcompare_elim = 354,                   /* -fcompare-elim */
  OPT_fcond_mismatch = 355,                  /* -fcond-mismatch */
  OPT_fconserve_space = 356,                 /* -fconserve-space */
  OPT_fconserve_stack = 357,                 /* -fconserve-stack */
  OPT_fconstant_string_class_ = 358,         /* -fconstant-string-class= */
  OPT_fconstexpr_depth_ = 359,               /* -fconstexpr-depth= */
  OPT_fcprop_registers = 360,                /* -fcprop-registers */
  OPT_fcrossjumping = 361,                   /* -fcrossjumping */
  OPT_fcse_follow_jumps = 362,               /* -fcse-follow-jumps */
  /* OPT_fcse_skip_blocks = 363, */          /* -fcse-skip-blocks */
  OPT_fcx_fortran_rules = 364,               /* -fcx-fortran-rules */
  OPT_fcx_limited_range = 365,               /* -fcx-limited-range */
  OPT_fdata_sections = 366,                  /* -fdata-sections */
  OPT_fdbg_cnt_list = 367,                   /* -fdbg-cnt-list */
  OPT_fdbg_cnt_ = 368,                       /* -fdbg-cnt= */
  OPT_fdce = 369,                            /* -fdce */
  OPT_fdebug_prefix_map_ = 370,              /* -fdebug-prefix-map= */
  OPT_fdeduce_init_list = 371,               /* -fdeduce-init-list */
  /* OPT_fdefault_inline = 372, */           /* -fdefault-inline */
  OPT_fdefer_pop = 373,                      /* -fdefer-pop */
  OPT_fdelayed_branch = 374,                 /* -fdelayed-branch */
  OPT_fdelete_null_pointer_checks = 375,     /* -fdelete-null-pointer-checks */
  OPT_fdevirtualize = 376,                   /* -fdevirtualize */
  OPT_fdiagnostics_show_location_ = 377,     /* -fdiagnostics-show-location= */
  OPT_fdiagnostics_show_option = 378,        /* -fdiagnostics-show-option */
  OPT_fdirectives_only = 379,                /* -fdirectives-only */
  OPT_fdollars_in_identifiers = 380,         /* -fdollars-in-identifiers */
  OPT_fdse = 381,                            /* -fdse */
  OPT_fdump_ = 382,                          /* -fdump- */
  OPT_fdump_final_insns = 383,               /* -fdump-final-insns */
  OPT_fdump_final_insns_ = 384,              /* -fdump-final-insns= */
  OPT_fdump_go_spec_ = 385,                  /* -fdump-go-spec= */
  OPT_fdump_noaddr = 386,                    /* -fdump-noaddr */
  OPT_fdump_unnumbered = 387,                /* -fdump-unnumbered */
  OPT_fdump_unnumbered_links = 388,          /* -fdump-unnumbered-links */
  OPT_fdwarf2_cfi_asm = 389,                 /* -fdwarf2-cfi-asm */
  OPT_fearly_inlining = 390,                 /* -fearly-inlining */
  OPT_felide_constructors = 391,             /* -felide-constructors */
  OPT_feliminate_dwarf2_dups = 392,          /* -feliminate-dwarf2-dups */
  OPT_feliminate_unused_debug_symbols = 393, /* -feliminate-unused-debug-symbols */
  OPT_feliminate_unused_debug_types = 394,   /* -feliminate-unused-debug-types */
  OPT_femit_class_debug_always = 395,        /* -femit-class-debug-always */
  OPT_femit_struct_debug_baseonly = 396,     /* -femit-struct-debug-baseonly */
  OPT_femit_struct_debug_detailed_ = 397,    /* -femit-struct-debug-detailed= */
  OPT_femit_struct_debug_reduced = 398,      /* -femit-struct-debug-reduced */
  OPT_fenable_icf_debug = 399,               /* -fenable-icf-debug */
  OPT_fenforce_eh_specs = 400,               /* -fenforce-eh-specs */
  /* OPT_fenum_int_equiv = 401, */           /* -fenum-int-equiv */
  OPT_fexceptions = 402,                     /* -fexceptions */
  OPT_fexcess_precision_ = 403,              /* -fexcess-precision= */
  OPT_fexec_charset_ = 404,                  /* -fexec-charset= */
  OPT_fexpensive_optimizations = 405,        /* -fexpensive-optimizations */
  OPT_fextended_identifiers = 406,           /* -fextended-identifiers */
  /* OPT_fexternal_templates = 407, */       /* -fexternal-templates */
  OPT_ffast_math = 408,                      /* -ffast-math */
  OPT_ffinite_math_only = 409,               /* -ffinite-math-only */
  OPT_ffixed_ = 410,                         /* -ffixed- */
  OPT_ffloat_store = 411,                    /* -ffloat-store */
  OPT_ffor_scope = 412,                      /* -ffor-scope */
  /* OPT_fforce_addr = 413, */               /* -fforce-addr */
  OPT_fforward_propagate = 414,              /* -fforward-propagate */
  OPT_ffp_contract_ = 415,                   /* -ffp-contract= */
  OPT_ffreestanding = 416,                   /* -ffreestanding */
  OPT_ffriend_injection = 417,               /* -ffriend-injection */
  OPT_ffunction_cse = 418,                   /* -ffunction-cse */
  OPT_ffunction_sections = 419,              /* -ffunction-sections */
  OPT_fgcse = 420,                           /* -fgcse */
  OPT_fgcse_after_reload = 421,              /* -fgcse-after-reload */
  OPT_fgcse_las = 422,                       /* -fgcse-las */
  OPT_fgcse_lm = 423,                        /* -fgcse-lm */
  OPT_fgcse_sm = 424,                        /* -fgcse-sm */
  OPT_fgnu_keywords = 425,                   /* -fgnu-keywords */
  OPT_fgnu_runtime = 426,                    /* -fgnu-runtime */
  OPT_fgnu89_inline = 427,                   /* -fgnu89-inline */
  OPT_fgraphite = 428,                       /* -fgraphite */
  OPT_fgraphite_identity = 429,              /* -fgraphite-identity */
  OPT_fguess_branch_probability = 430,       /* -fguess-branch-probability */
  /* OPT_fguiding_decls = 431, */            /* -fguiding-decls */
  /* OPT_fhandle_exceptions = 432, */        /* -fhandle-exceptions */
  /* OPT_fhelp = 433, */                     /* -fhelp */
  /* OPT_fhelp_ = 434, */                    /* -fhelp= */
  /* OPT_fhonor_std = 435, */                /* -fhonor-std */
  OPT_fhosted = 436,                         /* -fhosted */
  /* OPT_fhuge_objects = 437, */             /* -fhuge-objects */
  OPT_fident = 438,                          /* -fident */
  OPT_fif_conversion = 439,                  /* -fif-conversion */
  OPT_fif_conversion2 = 440,                 /* -fif-conversion2 */
  OPT_fimplement_inlines = 441,              /* -fimplement-inlines */
  OPT_fimplicit_inline_templates = 442,      /* -fimplicit-inline-templates */
  OPT_fimplicit_templates = 443,             /* -fimplicit-templates */
  OPT_findirect_inlining = 444,              /* -findirect-inlining */
  OPT_finhibit_size_directive = 445,         /* -finhibit-size-directive */
  OPT_finline = 446,                         /* -finline */
  OPT_finline_functions = 447,               /* -finline-functions */
  OPT_finline_functions_called_once = 448,   /* -finline-functions-called-once */
  /* OPT_finline_limit_ = 449, */            /* -finline-limit- */
  OPT_finline_limit_ = 450,                  /* -finline-limit= */
  OPT_finline_small_functions = 451,         /* -finline-small-functions */
  OPT_finput_charset_ = 452,                 /* -finput-charset= */
  OPT_finstrument_functions = 453,           /* -finstrument-functions */
  OPT_finstrument_functions_exclude_file_list_ = 454,/* -finstrument-functions-exclude-file-list= */
  OPT_finstrument_functions_exclude_function_list_ = 455,/* -finstrument-functions-exclude-function-list= */
  OPT_fipa_cp = 456,                         /* -fipa-cp */
  OPT_fipa_cp_clone = 457,                   /* -fipa-cp-clone */
  OPT_fipa_matrix_reorg = 458,               /* -fipa-matrix-reorg */
  OPT_fipa_profile = 459,                    /* -fipa-profile */
  OPT_fipa_pta = 460,                        /* -fipa-pta */
  OPT_fipa_pure_const = 461,                 /* -fipa-pure-const */
  OPT_fipa_reference = 462,                  /* -fipa-reference */
  OPT_fipa_sra = 463,                        /* -fipa-sra */
  OPT_fipa_struct_reorg = 464,               /* -fipa-struct-reorg */
  OPT_fira_algorithm_ = 465,                 /* -fira-algorithm= */
  OPT_fira_loop_pressure = 466,              /* -fira-loop-pressure */
  OPT_fira_region_ = 467,                    /* -fira-region= */
  OPT_fira_share_save_slots = 468,           /* -fira-share-save-slots */
  OPT_fira_share_spill_slots = 469,          /* -fira-share-spill-slots */
  OPT_fira_verbose_ = 470,                   /* -fira-verbose= */
  OPT_fivopts = 471,                         /* -fivopts */
  OPT_fjump_tables = 472,                    /* -fjump-tables */
  OPT_fkeep_inline_dllexport = 473,          /* -fkeep-inline-dllexport */
  OPT_fkeep_inline_functions = 474,          /* -fkeep-inline-functions */
  OPT_fkeep_static_consts = 475,             /* -fkeep-static-consts */
  /* OPT_flabels_ok = 476, */                /* -flabels-ok */
  OPT_flax_vector_conversions = 477,         /* -flax-vector-conversions */
  OPT_fleading_underscore = 478,             /* -fleading-underscore */
  OPT_floop_block = 479,                     /* -floop-block */
  OPT_floop_flatten = 480,                   /* -floop-flatten */
  OPT_floop_interchange = 481,               /* -floop-interchange */
  /* OPT_floop_optimize = 482, */            /* -floop-optimize */
  OPT_floop_parallelize_all = 483,           /* -floop-parallelize-all */
  OPT_floop_strip_mine = 484,                /* -floop-strip-mine */
  OPT_flto = 485,                            /* -flto */
  OPT_flto_compression_level_ = 486,         /* -flto-compression-level= */
  OPT_flto_partition_1to1 = 487,             /* -flto-partition=1to1 */
  OPT_flto_partition_balanced = 488,         /* -flto-partition=balanced */
  OPT_flto_partition_none = 489,             /* -flto-partition=none */
  OPT_flto_report = 490,                     /* -flto-report */
  OPT_flto_ = 491,                           /* -flto= */
  OPT_fltrans = 492,                         /* -fltrans */
  OPT_fltrans_output_list_ = 493,            /* -fltrans-output-list= */
  OPT_fmath_errno = 494,                     /* -fmath-errno */
  OPT_fmax_errors_ = 495,                    /* -fmax-errors= */
  OPT_fmem_report = 496,                     /* -fmem-report */
  OPT_fmerge_all_constants = 497,            /* -fmerge-all-constants */
  OPT_fmerge_constants = 498,                /* -fmerge-constants */
  OPT_fmerge_debug_strings = 499,            /* -fmerge-debug-strings */
  OPT_fmessage_length_ = 500,                /* -fmessage-length= */
  OPT_fmodulo_sched = 501,                   /* -fmodulo-sched */
  OPT_fmodulo_sched_allow_regmoves = 502,    /* -fmodulo-sched-allow-regmoves */
  OPT_fmove_loop_invariants = 503,           /* -fmove-loop-invariants */
  OPT_fms_extensions = 504,                  /* -fms-extensions */
  OPT_fmudflap = 505,                        /* -fmudflap */
  OPT_fmudflapir = 506,                      /* -fmudflapir */
  OPT_fmudflapth = 507,                      /* -fmudflapth */
  /* OPT_fname_mangling_version_ = 508, */   /* -fname-mangling-version- */
  /* OPT_fnew_abi = 509, */                  /* -fnew-abi */
  OPT_fnext_runtime = 510,                   /* -fnext-runtime */
  OPT_fnil_receivers = 511,                  /* -fnil-receivers */
  OPT_fnon_call_exceptions = 512,            /* -fnon-call-exceptions */
  OPT_fnonansi_builtins = 513,               /* -fnonansi-builtins */
  /* OPT_fnonnull_objects = 514, */          /* -fnonnull-objects */
  OPT_fnothrow_opt = 515,                    /* -fnothrow-opt */
  OPT_fobjc_abi_version_ = 516,              /* -fobjc-abi-version= */
  OPT_fobjc_call_cxx_cdtors = 517,           /* -fobjc-call-cxx-cdtors */
  OPT_fobjc_direct_dispatch = 518,           /* -fobjc-direct-dispatch */
  OPT_fobjc_exceptions = 519,                /* -fobjc-exceptions */
  OPT_fobjc_gc = 520,                        /* -fobjc-gc */
  OPT_fobjc_nilcheck = 521,                  /* -fobjc-nilcheck */
  OPT_fobjc_sjlj_exceptions = 522,           /* -fobjc-sjlj-exceptions */
  OPT_fobjc_std_objc1 = 523,                 /* -fobjc-std=objc1 */
  OPT_fomit_frame_pointer = 524,             /* -fomit-frame-pointer */
  OPT_fopenmp = 525,                         /* -fopenmp */
  OPT_foperator_names = 526,                 /* -foperator-names */
  OPT_foptimize_register_move = 527,         /* -foptimize-register-move */
  OPT_foptimize_sibling_calls = 528,         /* -foptimize-sibling-calls */
  /* OPT_foptional_diags = 529, */           /* -foptional-diags */
  OPT_fpack_struct = 530,                    /* -fpack-struct */
  OPT_fpack_struct_ = 531,                   /* -fpack-struct= */
  OPT_fpartial_inlining = 532,               /* -fpartial-inlining */
  OPT_fpcc_struct_return = 533,              /* -fpcc-struct-return */
  OPT_fpch_deps = 534,                       /* -fpch-deps */
  OPT_fpch_preprocess = 535,                 /* -fpch-preprocess */
  OPT_fpeel_loops = 536,                     /* -fpeel-loops */
  OPT_fpeephole = 537,                       /* -fpeephole */
  OPT_fpeephole2 = 538,                      /* -fpeephole2 */
  OPT_fpermissive = 539,                     /* -fpermissive */
  OPT_fpic = 540,                            /* -fpic */
  OPT_fpie = 541,                            /* -fpie */
  OPT_fplan9_extensions = 542,               /* -fplan9-extensions */
  OPT_fplugin_arg_ = 543,                    /* -fplugin-arg- */
  OPT_fplugin_ = 544,                        /* -fplugin= */
  OPT_fpost_ipa_mem_report = 545,            /* -fpost-ipa-mem-report */
  OPT_fpre_ipa_mem_report = 546,             /* -fpre-ipa-mem-report */
  OPT_fpredictive_commoning = 547,           /* -fpredictive-commoning */
  OPT_fprefetch_loop_arrays = 548,           /* -fprefetch-loop-arrays */
  OPT_fpreprocessed = 549,                   /* -fpreprocessed */
  OPT_fpretty_templates = 550,               /* -fpretty-templates */
  OPT_fprofile = 551,                        /* -fprofile */
  OPT_fprofile_arcs = 552,                   /* -fprofile-arcs */
  OPT_fprofile_correction = 553,             /* -fprofile-correction */
  OPT_fprofile_dir_ = 554,                   /* -fprofile-dir= */
  OPT_fprofile_generate = 555,               /* -fprofile-generate */
  OPT_fprofile_generate_ = 556,              /* -fprofile-generate= */
  OPT_fprofile_use = 557,                    /* -fprofile-use */
  OPT_fprofile_use_ = 558,                   /* -fprofile-use= */
  OPT_fprofile_values = 559,                 /* -fprofile-values */
  OPT_frandom_seed = 560,                    /* -frandom-seed */
  OPT_frandom_seed_ = 561,                   /* -frandom-seed= */
  OPT_freciprocal_math = 562,                /* -freciprocal-math */
  OPT_frecord_gcc_switches = 563,            /* -frecord-gcc-switches */
  OPT_freg_struct_return = 564,              /* -freg-struct-return */
  OPT_fregmove = 565,                        /* -fregmove */
  OPT_frename_registers = 566,               /* -frename-registers */
  OPT_freorder_blocks = 567,                 /* -freorder-blocks */
  OPT_freorder_blocks_and_partition = 568,   /* -freorder-blocks-and-partition */
  OPT_freorder_functions = 569,              /* -freorder-functions */
  OPT_freplace_objc_classes = 570,           /* -freplace-objc-classes */
  OPT_frepo = 571,                           /* -frepo */
  OPT_frerun_cse_after_loop = 572,           /* -frerun-cse-after-loop */
  /* OPT_frerun_loop_opt = 573, */           /* -frerun-loop-opt */
  OPT_freschedule_modulo_scheduled_loops = 574,/* -freschedule-modulo-scheduled-loops */
  OPT_fresolution_ = 575,                    /* -fresolution= */
  OPT_frounding_math = 576,                  /* -frounding-math */
  OPT_frtti = 577,                           /* -frtti */
  OPT_fsched_critical_path_heuristic = 578,  /* -fsched-critical-path-heuristic */
  OPT_fsched_dep_count_heuristic = 579,      /* -fsched-dep-count-heuristic */
  OPT_fsched_group_heuristic = 580,          /* -fsched-group-heuristic */
  OPT_fsched_interblock = 581,               /* -fsched-interblock */
  OPT_fsched_last_insn_heuristic = 582,      /* -fsched-last-insn-heuristic */
  OPT_fsched_pressure = 583,                 /* -fsched-pressure */
  OPT_fsched_rank_heuristic = 584,           /* -fsched-rank-heuristic */
  OPT_fsched_spec = 585,                     /* -fsched-spec */
  OPT_fsched_spec_insn_heuristic = 586,      /* -fsched-spec-insn-heuristic */
  OPT_fsched_spec_load = 587,                /* -fsched-spec-load */
  OPT_fsched_spec_load_dangerous = 588,      /* -fsched-spec-load-dangerous */
  OPT_fsched_stalled_insns = 589,            /* -fsched-stalled-insns */
  OPT_fsched_stalled_insns_dep = 590,        /* -fsched-stalled-insns-dep */
  OPT_fsched_stalled_insns_dep_ = 591,       /* -fsched-stalled-insns-dep= */
  OPT_fsched_stalled_insns_ = 592,           /* -fsched-stalled-insns= */
  OPT_fsched_verbose_ = 593,                 /* -fsched-verbose= */
  OPT_fsched2_use_superblocks = 594,         /* -fsched2-use-superblocks */
  /* OPT_fsched2_use_traces = 595, */        /* -fsched2-use-traces */
  OPT_fschedule_insns = 596,                 /* -fschedule-insns */
  OPT_fschedule_insns2 = 597,                /* -fschedule-insns2 */
  OPT_fsection_anchors = 598,                /* -fsection-anchors */
  /* OPT_fsee = 599, */                      /* -fsee */
  OPT_fsel_sched_pipelining = 600,           /* -fsel-sched-pipelining */
  OPT_fsel_sched_pipelining_outer_loops = 601,/* -fsel-sched-pipelining-outer-loops */
  OPT_fsel_sched_reschedule_pipelined = 602, /* -fsel-sched-reschedule-pipelined */
  OPT_fselective_scheduling = 603,           /* -fselective-scheduling */
  OPT_fselective_scheduling2 = 604,          /* -fselective-scheduling2 */
  OPT_fshort_double = 605,                   /* -fshort-double */
  OPT_fshort_enums = 606,                    /* -fshort-enums */
  OPT_fshort_wchar = 607,                    /* -fshort-wchar */
  OPT_fshow_column = 608,                    /* -fshow-column */
  OPT_fsignaling_nans = 609,                 /* -fsignaling-nans */
  OPT_fsigned_bitfields = 610,               /* -fsigned-bitfields */
  OPT_fsigned_char = 611,                    /* -fsigned-char */
  OPT_fsigned_zeros = 612,                   /* -fsigned-zeros */
  OPT_fsingle_precision_constant = 613,      /* -fsingle-precision-constant */
  OPT_fsplit_ivs_in_unroller = 614,          /* -fsplit-ivs-in-unroller */
  OPT_fsplit_stack = 615,                    /* -fsplit-stack */
  OPT_fsplit_wide_types = 616,               /* -fsplit-wide-types */
  /* OPT_fsquangle = 617, */                 /* -fsquangle */
  /* OPT_fstack_check = 618, */              /* -fstack-check */
  OPT_fstack_check_ = 619,                   /* -fstack-check= */
  OPT_fstack_limit = 620,                    /* -fstack-limit */
  OPT_fstack_limit_register_ = 621,          /* -fstack-limit-register= */
  OPT_fstack_limit_symbol_ = 622,            /* -fstack-limit-symbol= */
  OPT_fstack_protector = 623,                /* -fstack-protector */
  OPT_fstack_protector_all = 624,            /* -fstack-protector-all */
  OPT_fstack_usage = 625,                    /* -fstack-usage */
  OPT_fstats = 626,                          /* -fstats */
  /* OPT_fstrength_reduce = 627, */          /* -fstrength-reduce */
  OPT_fstrict_aliasing = 628,                /* -fstrict-aliasing */
  OPT_fstrict_enums = 629,                   /* -fstrict-enums */
  OPT_fstrict_overflow = 630,                /* -fstrict-overflow */
  /* OPT_fstrict_prototype = 631, */         /* -fstrict-prototype */
  OPT_fstrict_volatile_bitfields = 632,      /* -fstrict-volatile-bitfields */
  OPT_fsyntax_only = 633,                    /* -fsyntax-only */
  OPT_ftabstop_ = 634,                       /* -ftabstop= */
  /* OPT_ftarget_help = 635, */              /* -ftarget-help */
  /* OPT_ftemplate_depth_ = 636, */          /* -ftemplate-depth- */
  OPT_ftemplate_depth_ = 637,                /* -ftemplate-depth= */
  OPT_ftest_coverage = 638,                  /* -ftest-coverage */
  /* OPT_fthis_is_variable = 639, */         /* -fthis-is-variable */
  OPT_fthread_jumps = 640,                   /* -fthread-jumps */
  OPT_fthreadsafe_statics = 641,             /* -fthreadsafe-statics */
  OPT_ftime_report = 642,                    /* -ftime-report */
  OPT_ftls_model_ = 643,                     /* -ftls-model= */
  OPT_ftoplevel_reorder = 644,               /* -ftoplevel-reorder */
  OPT_ftracer = 645,                         /* -ftracer */
  OPT_ftrapping_math = 646,                  /* -ftrapping-math */
  OPT_ftrapv = 647,                          /* -ftrapv */
  OPT_ftree_bit_ccp = 648,                   /* -ftree-bit-ccp */
  OPT_ftree_builtin_call_dce = 649,          /* -ftree-builtin-call-dce */
  OPT_ftree_ccp = 650,                       /* -ftree-ccp */
  OPT_ftree_ch = 651,                        /* -ftree-ch */
  OPT_ftree_copy_prop = 652,                 /* -ftree-copy-prop */
  OPT_ftree_copyrename = 653,                /* -ftree-copyrename */
  OPT_ftree_cselim = 654,                    /* -ftree-cselim */
  OPT_ftree_dce = 655,                       /* -ftree-dce */
  OPT_ftree_dominator_opts = 656,            /* -ftree-dominator-opts */
  OPT_ftree_dse = 657,                       /* -ftree-dse */
  OPT_ftree_forwprop = 658,                  /* -ftree-forwprop */
  OPT_ftree_fre = 659,                       /* -ftree-fre */
  OPT_ftree_loop_distribute_patterns = 660,  /* -ftree-loop-distribute-patterns */
  OPT_ftree_loop_distribution = 661,         /* -ftree-loop-distribution */
  OPT_ftree_loop_if_convert = 662,           /* -ftree-loop-if-convert */
  OPT_ftree_loop_if_convert_stores = 663,    /* -ftree-loop-if-convert-stores */
  OPT_ftree_loop_im = 664,                   /* -ftree-loop-im */
  OPT_ftree_loop_ivcanon = 665,              /* -ftree-loop-ivcanon */
  /* OPT_ftree_loop_linear = 666, */         /* -ftree-loop-linear */
  OPT_ftree_loop_optimize = 667,             /* -ftree-loop-optimize */
  OPT_ftree_lrs = 668,                       /* -ftree-lrs */
  OPT_ftree_parallelize_loops_ = 669,        /* -ftree-parallelize-loops= */
  OPT_ftree_phiprop = 670,                   /* -ftree-phiprop */
  OPT_ftree_pre = 671,                       /* -ftree-pre */
  OPT_ftree_pta = 672,                       /* -ftree-pta */
  OPT_ftree_reassoc = 673,                   /* -ftree-reassoc */
  /* OPT_ftree_salias = 674, */              /* -ftree-salias */
  OPT_ftree_scev_cprop = 675,                /* -ftree-scev-cprop */
  OPT_ftree_sink = 676,                      /* -ftree-sink */
  OPT_ftree_slp_vectorize = 677,             /* -ftree-slp-vectorize */
  OPT_ftree_sra = 678,                       /* -ftree-sra */
  /* OPT_ftree_store_ccp = 679, */           /* -ftree-store-ccp */
  /* OPT_ftree_store_copy_prop = 680, */     /* -ftree-store-copy-prop */
  OPT_ftree_switch_conversion = 681,         /* -ftree-switch-conversion */
  OPT_ftree_ter = 682,                       /* -ftree-ter */
  OPT_ftree_vect_loop_version = 683,         /* -ftree-vect-loop-version */
  OPT_ftree_vectorize = 684,                 /* -ftree-vectorize */
  OPT_ftree_vectorizer_verbose_ = 685,       /* -ftree-vectorizer-verbose= */
  OPT_ftree_vrp = 686,                       /* -ftree-vrp */
  OPT_funit_at_a_time = 687,                 /* -funit-at-a-time */
  OPT_funroll_all_loops = 688,               /* -funroll-all-loops */
  OPT_funroll_loops = 689,                   /* -funroll-loops */
  OPT_funsafe_loop_optimizations = 690,      /* -funsafe-loop-optimizations */
  OPT_funsafe_math_optimizations = 691,      /* -funsafe-math-optimizations */
  OPT_funsigned_bitfields = 692,             /* -funsigned-bitfields */
  OPT_funsigned_char = 693,                  /* -funsigned-char */
  OPT_funswitch_loops = 694,                 /* -funswitch-loops */
  OPT_funwind_tables = 695,                  /* -funwind-tables */
  OPT_fuse_cxa_atexit = 696,                 /* -fuse-cxa-atexit */
  OPT_fuse_cxa_get_exception_ptr = 697,      /* -fuse-cxa-get-exception-ptr */
  OPT_fuse_linker_plugin = 698,              /* -fuse-linker-plugin */
  OPT_fvar_tracking = 699,                   /* -fvar-tracking */
  OPT_fvar_tracking_assignments = 700,       /* -fvar-tracking-assignments */
  OPT_fvar_tracking_assignments_toggle = 701,/* -fvar-tracking-assignments-toggle */
  OPT_fvar_tracking_uninit = 702,            /* -fvar-tracking-uninit */
  OPT_fvariable_expansion_in_unroller = 703, /* -fvariable-expansion-in-unroller */
  OPT_fvect_cost_model = 704,                /* -fvect-cost-model */
  OPT_fverbose_asm = 705,                    /* -fverbose-asm */
  /* OPT_fversion = 706, */                  /* -fversion */
  OPT_fvisibility_inlines_hidden = 707,      /* -fvisibility-inlines-hidden */
  OPT_fvisibility_ms_compat = 708,           /* -fvisibility-ms-compat */
  OPT_fvisibility_ = 709,                    /* -fvisibility= */
  OPT_fvpt = 710,                            /* -fvpt */
  /* OPT_fvtable_gc = 711, */                /* -fvtable-gc */
  /* OPT_fvtable_thunks = 712, */            /* -fvtable-thunks */
  OPT_fweak = 713,                           /* -fweak */
  OPT_fweb = 714,                            /* -fweb */
  OPT_fwhole_program = 715,                  /* -fwhole-program */
  OPT_fwide_exec_charset_ = 716,             /* -fwide-exec-charset= */
  OPT_fworking_directory = 717,              /* -fworking-directory */
  OPT_fwpa = 718,                            /* -fwpa */
  OPT_fwrapv = 719,                          /* -fwrapv */
  /* OPT_fxref = 720, */                     /* -fxref */
  OPT_fzee = 721,                            /* -fzee */
  OPT_fzero_initialized_in_bss = 722,        /* -fzero-initialized-in-bss */
  OPT_fzero_link = 723,                      /* -fzero-link */
  OPT_g = 724,                               /* -g */
  OPT_gcoff = 725,                           /* -gcoff */
  OPT_gdwarf_ = 726,                         /* -gdwarf- */
  OPT_gen_decls = 727,                       /* -gen-decls */
  OPT_ggdb = 728,                            /* -ggdb */
  OPT_gno_strict_dwarf = 729,                /* -gno-strict-dwarf */
  OPT_gstabs = 730,                          /* -gstabs */
  OPT_gstabs_ = 731,                         /* -gstabs+ */
  OPT_gstrict_dwarf = 732,                   /* -gstrict-dwarf */
  OPT_gtoggle = 733,                         /* -gtoggle */
  OPT_gvms = 734,                            /* -gvms */
  OPT_gxcoff = 735,                          /* -gxcoff */
  OPT_gxcoff_ = 736,                         /* -gxcoff+ */
  OPT_h = 737,                               /* -h */
  OPT_idirafter = 738,                       /* -idirafter */
  OPT_imacros = 739,                         /* -imacros */
  OPT_imultilib = 740,                       /* -imultilib */
  OPT_include = 741,                         /* -include */
  OPT_iplugindir_ = 742,                     /* -iplugindir= */
  OPT_iprefix = 743,                         /* -iprefix */
  OPT_iquote = 744,                          /* -iquote */
  OPT_isysroot = 745,                        /* -isysroot */
  OPT_isystem = 746,                         /* -isystem */
  OPT_iwithprefix = 747,                     /* -iwithprefix */
  OPT_iwithprefixbefore = 748,               /* -iwithprefixbefore */
  OPT_l = 749,                               /* -l */
  OPT_lang_asm = 750,                        /* -lang-asm */
  OPT_mcpu_ = 751,                           /* -mcpu= */
  OPT_mdisable_hwmul = 752,                  /* -mdisable-hwmul */
  OPT_mdisable_watchdog = 753,               /* -mdisable-watchdog */
  OPT_menable_libcall_shift = 754,           /* -menable-libcall-shift */
  OPT_minline_hwmul = 755,                   /* -minline-hwmul */
  OPT_mivcnt_ = 756,                         /* -mivcnt= */
  OPT_mmcu_ = 757,                           /* -mmcu= */
  OPT_mmpy_ = 758,                           /* -mmpy= */
  OPT_mno_volatile_workaround = 759,         /* -mno-volatile-workaround */
  OPT_mnoint_hwmul = 760,                    /* -mnoint-hwmul */
  OPT_msave_prologue = 761,                  /* -msave-prologue */
  OPT_n = 762,                               /* -n */
  OPT_no_canonical_prefixes = 763,           /* -no-canonical-prefixes */
  OPT_no_integrated_cpp = 764,               /* -no-integrated-cpp */
  OPT_nodefaultlibs = 765,                   /* -nodefaultlibs */
  OPT_nostartfiles = 766,                    /* -nostartfiles */
  OPT_nostdinc = 767,                        /* -nostdinc */
  OPT_nostdinc__ = 768,                      /* -nostdinc++ */
  OPT_nostdlib = 769,                        /* -nostdlib */
  OPT_o = 770,                               /* -o */
  OPT_p = 771,                               /* -p */
  OPT_pass_exit_codes = 772,                 /* -pass-exit-codes */
  OPT_pedantic = 773,                        /* -pedantic */
  OPT_pedantic_errors = 774,                 /* -pedantic-errors */
  OPT_pg = 775,                              /* -pg */
  OPT_pie = 776,                             /* -pie */
  OPT_pipe = 777,                            /* -pipe */
  OPT_print_file_name_ = 778,                /* -print-file-name= */
  OPT_print_libgcc_file_name = 779,          /* -print-libgcc-file-name */
  OPT_print_multi_directory = 780,           /* -print-multi-directory */
  OPT_print_multi_lib = 781,                 /* -print-multi-lib */
  OPT_print_multi_os_directory = 782,        /* -print-multi-os-directory */
  OPT_print_objc_runtime_info = 783,         /* -print-objc-runtime-info */
  OPT_print_prog_name_ = 784,                /* -print-prog-name= */
  OPT_print_search_dirs = 785,               /* -print-search-dirs */
  OPT_print_sysroot = 786,                   /* -print-sysroot */
  OPT_print_sysroot_headers_suffix = 787,    /* -print-sysroot-headers-suffix */
  OPT_quiet = 788,                           /* -quiet */
  OPT_r = 789,                               /* -r */
  OPT_remap = 790,                           /* -remap */
  OPT_s = 791,                               /* -s */
  OPT_save_temps = 792,                      /* -save-temps */
  OPT_save_temps_ = 793,                     /* -save-temps= */
  OPT_shared = 794,                          /* -shared */
  OPT_shared_libgcc = 795,                   /* -shared-libgcc */
  /* OPT_specs = 796, */                     /* -specs */
  OPT_specs_ = 797,                          /* -specs= */
  OPT_static = 798,                          /* -static */
  OPT_static_libgcc = 799,                   /* -static-libgcc */
  OPT_static_libgfortran = 800,              /* -static-libgfortran */
  OPT_static_libgo = 801,                    /* -static-libgo */
  OPT_static_libstdc__ = 802,                /* -static-libstdc++ */
  /* OPT_std_c__03 = 803, */                 /* -std=c++03 */
  OPT_std_c__0x = 804,                       /* -std=c++0x */
  OPT_std_c__98 = 805,                       /* -std=c++98 */
  OPT_std_c1x = 806,                         /* -std=c1x */
  /* OPT_std_c89 = 807, */                   /* -std=c89 */
  OPT_std_c90 = 808,                         /* -std=c90 */
  OPT_std_c99 = 809,                         /* -std=c99 */
  /* OPT_std_c9x = 810, */                   /* -std=c9x */
  OPT_std_gnu__0x = 811,                     /* -std=gnu++0x */
  OPT_std_gnu__98 = 812,                     /* -std=gnu++98 */
  OPT_std_gnu1x = 813,                       /* -std=gnu1x */
  /* OPT_std_gnu89 = 814, */                 /* -std=gnu89 */
  OPT_std_gnu90 = 815,                       /* -std=gnu90 */
  OPT_std_gnu99 = 816,                       /* -std=gnu99 */
  /* OPT_std_gnu9x = 817, */                 /* -std=gnu9x */
  /* OPT_std_iso9899_1990 = 818, */          /* -std=iso9899:1990 */
  OPT_std_iso9899_199409 = 819,              /* -std=iso9899:199409 */
  /* OPT_std_iso9899_1999 = 820, */          /* -std=iso9899:1999 */
  /* OPT_std_iso9899_199x = 821, */          /* -std=iso9899:199x */
  OPT_symbolic = 822,                        /* -symbolic */
  OPT_t = 823,                               /* -t */
  OPT_time = 824,                            /* -time */
  OPT_time_ = 825,                           /* -time= */
  OPT_traditional = 826,                     /* -traditional */
  OPT_traditional_cpp = 827,                 /* -traditional-cpp */
  OPT_trigraphs = 828,                       /* -trigraphs */
  OPT_u = 829,                               /* -u */
  OPT_undef = 830,                           /* -undef */
  OPT_v = 831,                               /* -v */
  OPT_version = 832,                         /* -version */
  OPT_w = 833,                               /* -w */
  OPT_wrapper = 834,                         /* -wrapper */
  OPT_x = 835,                               /* -x */
  OPT_z = 836,                               /* -z */
  N_OPTS,
  OPT_SPECIAL_unknown,
  OPT_SPECIAL_ignore,
  OPT_SPECIAL_program_name,
  OPT_SPECIAL_input_file
};

#endif /* OPTIONS_H */
